@@ -1,6 +1,6 @@
 /* acontainer.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2019 Ralf Hoffmann.
+ * Copyright (C) 2004-2024 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,12 +35,14 @@ public:
   AContainer &operator=( const AContainer &other );
 
   enum { ACONT_NONE = 0,
-	 ACONT_MAXW = 1,
-	 ACONT_MAXH = 2,
-	 ACONT_MINW = 4,
-	 ACONT_MINH = 8,
-	 ACONT_NORESIZE = 16,
-         ACONT_CENTER = 32 };
+         ACONT_MAXW = 1 << 0,
+         ACONT_MAXH = 1 << 1,
+         ACONT_MINW = 1 << 2,
+         ACONT_MINH = 1 << 3,
+         ACONT_NORESIZE = 1 << 4,
+         ACONT_CENTERH = 1 << 5,
+         ACONT_CENTERV = 1 << 6,
+         ACONT_CENTER = ACONT_CENTERH | ACONT_CENTERV };
 
   static const int CO_INCW = ACONT_MINH + ACONT_MINW + ACONT_MAXH;
   static const int CO_INCWNR = CO_INCW + ACONT_NORESIZE;
@@ -134,8 +136,16 @@ public:
 
     bool noResize() const;
     void noResize( bool nv );
-    bool center() const;
-    void center( bool nv );
+
+    enum acont_elem_center_mode {
+        CENTER_NONE = 0,
+        CENTER_VERTICALLY = 1 << 0,
+        CENTER_HORIZONTALLY = 1 << 1,
+        CENTER_BOTH = CENTER_VERTICALLY | CENTER_HORIZONTALLY
+    };
+
+    enum acont_elem_center_mode center() const;
+    void center( enum acont_elem_center_mode nv );
   private:
     class Widget *_widelem;
     AContainer *Cont;
@@ -145,7 +155,7 @@ public:
     int AutosizeMode;
     int WWeight, HWeight;
     bool NoResize;
-    bool m_center;
+    enum acont_elem_center_mode m_center = CENTER_NONE;
   };
 
   struct update_infos {
