@@ -207,6 +207,13 @@ public:
         CLIPBOARD_REQUEST_FILE_LIST
     };
 
+    enum mouse_click_mode {
+        NO_CLICK,
+        NORMAL_CLICK,
+        DOUBLE_CLICK,
+        TRIPLE_CLICK
+    };
+
   int startCut(GUIElement *elem,const char *buffer, bool use_clipboard);
   void cancelCut(bool use_clipboard);
   bool amiOwner(bool use_clipboard) const;
