@@ -1,6 +1,6 @@
 /* aguixcolor.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2007-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,3 +35,16 @@ AGUIXColor::color_type_t AGUIXColor::getColorType() const
 {
     return m_color_type;
 }
+
+bool AGUIXColor::operator<( const AGUIXColor &other ) const
+{
+    if ( getColorType() == AGUIXColor::SYSTEM_COLOR &&
+         other.getColorType() != AGUIXColor::SYSTEM_COLOR ) return true;
+    if ( getColorType() == AGUIXColor::USER_COLOR &&
+         other.getColorType() == AGUIXColor::SYSTEM_COLOR ) return false;
+    if ( getColorType() == AGUIXColor::USER_COLOR &&
+         other.getColorType() == AGUIXColor::EXTRA_COLOR ) return true;
+    if ( getColorType() == AGUIXColor::EXTRA_COLOR &&
+         other.getColorType() != AGUIXColor::EXTRA_COLOR ) return false;
+    return getColor() < other.getColor();
+}
