@@ -68,7 +68,4 @@
    +1 for null byte */
 #define A_BYTESFORNUMBER(x) ( sizeof( x ) * 3 + 1 + 1 )
 
-#define MAX_X_WINDOW_WIDTH 2047
-#define MAX_X_WINDOW_HEIGHT 2047
-
 #endif
