@@ -229,7 +229,9 @@ int AGUIXFont::textWidth( const char *str, int count ) const
 {
     int w = 0;
 
-    XGlyphInfo extents;
+    if ( count == 0 ) return 0;
+
+    XGlyphInfo extents = { 0 };
 
     // since extents overflows if str is too long. But splitting UTF8
     // strings might not be correct for all characters so try to find
@@ -283,7 +285,6 @@ int AGUIXFont::textWidth( const char *str, int count ) const
                                     (XftChar8*)str,
                                     count,
                                     &extents );
-                //printf("BOO4:%d\n",extents.xOff);
                 break;
             }
         } else {
