@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2022 Ralf Hoffmann.
+ * Copyright (C) 2001-2025 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -970,6 +970,21 @@ int AWindow::request( const char *reqtitle, const char *text, const char *button
   return req->request( reqtitle, text, buttons, flags );
 }
 
+int AWindow::request( const char *reqtitle,
+                      const char *text,
+                      const std::vector< std::vector< std::pair< std::string, int > > > &button_rows,
+                      Requester::request_flags_t flags )
+{
+    if ( _parent != NULL ) {
+        return _parent->request( reqtitle, text, button_rows, flags );
+    }
+
+    if ( req == NULL ) {
+        req = new Requester( _aguix, this );
+    }
+    return req->request( reqtitle, text, button_rows, NULL, flags );
+}
+
 int AWindow::string_request( const char *reqtitle, const char *lines, const char *default_str, const char *buttons, char **return_str, Requester::request_flags_t flags )
 {
   if ( _parent != NULL ) {
@@ -1138,8 +1153,12 @@ void AWindow::doCreateStuff()
   WMHints = XAllocWMHints();
   if ( WMHints ) {
       WMHints->input = True;
+#if 0
       WMHints->window_group = _aguix->getGroupWin();
       WMHints->flags = InputHint | WindowGroupHint;
+#else
+      WMHints->flags = InputHint;
+#endif
       XSetWMHints( dsp, win, WMHints );
       XFree( WMHints );
   }
@@ -1693,3 +1712,12 @@ void AWindow::applyIcon()
                      _aguix->getAtom( AGUIX::CARDINAL_ATOM ),
                      32, PropModeReplace, (const unsigned char*)data, data_length );
 }
+
+void AWindow::setOverrideRedirect()
+{
+    if ( ! _created ) return;
+
+    XSetWindowAttributes set_attr;
+    set_attr.override_redirect = True;
+    XChangeWindowAttributes( _aguix->getDisplay(), win, CWOverrideRedirect, &set_attr );
+}
