@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2022 Ralf Hoffmann.
+ * Copyright (C) 2001-2025 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -136,6 +136,10 @@ public:
                const char *text,
                const char *buttons,
                Requester::request_flags_t flags = Requester::REQUEST_NONE );
+  int request( const char *reqtitle,
+               const char *text,
+               const std::vector< std::vector< std::pair< std::string, int > > > &button_rows,
+               Requester::request_flags_t flags = Requester::REQUEST_NONE );
   int string_request( const char *reqtitle,
                       const char *lines,
                       const char *default_str,
@@ -195,6 +199,8 @@ public:
   bool acceptXDND();
 
   Widget *findWidgetForRootPos( int rx, int ry );
+
+  void setOverrideRedirect();
 protected:
   bool onScreen;
   int _bg;
