@@ -1,6 +1,6 @@
 /* button.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -869,3 +869,13 @@ bool Button::getStrikeOut() const
 {
     return m_strike_out;
 }
+
+void Button::maximize( bool grow_only )
+{
+    int mw = getMaximumWidth();
+
+    if ( ! grow_only || mw > getWidth() ) {
+        resize( mw,
+                getHeight() );
+    }
+}
