@@ -1,6 +1,6 @@
 /* condvar.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2002-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -34,7 +34,6 @@ public:
   CondVar &operator=( const CondVar &other );
 
   virtual void wait();
-  virtual void timedWaitRel( int microseconds );
   virtual void signal();
   virtual void bcast();
 protected:
