@@ -255,7 +255,8 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
   
   if ( isCreated() == false ) return false;
 
-  returnvalue=false;
+  returnvalue = GUIElement::handleMessage( E, msg );
+
   AGMessage *agmsg;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
     if ( msg->window == win ) {
