@@ -211,22 +211,16 @@ public:
   void setDefaultColorMode( precolor_t mode );
 
   struct on_demand_data {
-      on_demand_data() : done( false ),
-                         text_set( false ),
-                         segments_set( false ),
-                         strike_out_set( false )
-      {}
-      
-      bool done;  // indicates that the caller is done with ondemand data
+      bool done = false;  // indicates that the caller is done with ondemand data
 
       std::string text; // the text for the given row x column
-      bool text_set;
+      bool text_set = false;
 
       std::vector< size_t > segments; // highlight segments
-      bool segments_set;
+      bool segments_set = false;
 
-      bool strike_out;
-      bool strike_out_set;
+      bool strike_out = false;
+      bool strike_out_set = false;
 
       size_t strike_out_start = 0;
       bool strike_out_start_set = false;
