@@ -79,10 +79,12 @@ void FieldListViewDND::handleSelect(Message *msg)
                             ti = CC_NORMAL;
                     }
 
-                    const char *tstr = NULL;
-                    if ( clickLastSelectedRow >= 0 && clickLastSelectedRow < (int)dndtexts.size() )
-                        tstr = dndtexts[clickLastSelectedRow].c_str();
-                    if ( tstr == NULL ) tstr = ( elementarray[ clickLastSelectedRow ]->getText( 0 ) ).c_str();
+                    std::string tstr;
+                    if ( clickLastSelectedRow >= 0 && clickLastSelectedRow < (int)dndtexts.size() ) {
+                        tstr = dndtexts[clickLastSelectedRow];
+                    } else {
+                        tstr = elementarray[ clickLastSelectedRow ]->getText( 0 );
+                    }
 
                     FieldLVRowData *dp = getDataExt( clickLastSelectedRow );
 
@@ -96,7 +98,7 @@ void FieldListViewDND::handleSelect(Message *msg)
                     }
 
                     dndtext = new DNDText( _aguix,
-                                           tstr,
+                                           tstr.c_str(),
                                            getFG( clickLastSelectedRow, ti ),
                                            getBG( clickLastSelectedRow, ti),
                                            font );
