@@ -150,7 +150,7 @@ bool GUIElement::isParent(Window twin) const
   return false;
 }
 
-void GUIElement::paste(unsigned char*buf)
+void GUIElement::paste( const unsigned char *content )
 {
 }
 
