@@ -1,6 +1,6 @@
 /* guielement.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -53,7 +53,7 @@ public:
   bool hasWin(Window win) const;
   Window getWindow() const;
   bool isParent(Window) const;
-  virtual void paste(unsigned char*);
+  virtual void paste( const unsigned char *content );
   virtual void cancelpaste();
   virtual void cancelcut();
   virtual void takeFocus();
