@@ -106,7 +106,7 @@ void KarteiButton::redraw()
   m_width_per_option.clear();
   m_width_per_option.resize( getNrOfOptions(), 0 );
 
-  if ( m_shrinker.getVal() != NULL ) {
+  if ( m_shrinker.get() != NULL ) {
       // calculate widths for each option
       int rem_width = 0;
       int rem_options = getNrOfOptions();
@@ -285,7 +285,7 @@ void KarteiButton::redraw()
               col = _aguix->getFaces().getAGUIXColor( "tab-active-fg" );
           }
 
-          if ( m_shrinker.getVal() != NULL ) {
+          if ( m_shrinker.get() != NULL ) {
               std::string current_text = m_shrinker->shrink( tstr, m_width_per_option[i], lencalc );
               _aguix->DrawText( dc, font, current_text.c_str(), sx + dx + delx, 1,
                                 col );
