@@ -294,8 +294,8 @@ char *AGUIX_catTrustedAndUnTrusted( const char *str1, const char *str2 )
   int quotemode = 0; /* 0 means no quote
 			1 means in single quotes
 			2 means in double quotes */
-  int i, o, lenstr1, lenstr2, sqcount;
-  char *newstr2, *newstr, *tstr1;
+  int i, o, lenstr2, sqcount;
+  char *newstr2, *tstr1;
 
   if ( ( str1 == NULL ) || ( str2 == NULL ) ) return NULL;
 
@@ -304,8 +304,6 @@ char *AGUIX_catTrustedAndUnTrusted( const char *str1, const char *str2 )
   tstr1 = AGUIX_fixBackslashed( str1 );
   if ( tstr1 == NULL ) return NULL;
 
-  lenstr1 = strlen( tstr1 );
-
   quotemode = AGUIX_getQuoteMode( tstr1 );
   if ( quotemode < 0 ) return NULL;
 
@@ -349,27 +347,34 @@ char *AGUIX_catTrustedAndUnTrusted( const char *str1, const char *str2 )
   // perhaps a closing double quote and a beginning single quote
   // strlen( newfilename )
   // perhaps a closing single quote and beginning double quote
-  newstr = (char*)_allocsafe( lenstr1 + 2 + strlen( newstr2 ) + 2 + 1 );
+  std::string newstr;
   switch ( quotemode ) {
   case 1:
     // single quote so no need for quote changing
     // remember newfilename is correctly quoted to live inside
     // single quote
-    sprintf( newstr, "%s%s", tstr1, newstr2 );
+    newstr = tstr1;
+    newstr += newstr2;
     break;
   case 2:
     // double quotes so close double quotes, begin single quote
     // and after newfilename close single quote and start double quote
-    sprintf( newstr, "%s\"'%s'\"", tstr1, newstr2 );
+    newstr = tstr1;
+    newstr += "\"'";
+    newstr += newstr2;
+    newstr += "'\"";
     break;
   default:
     // no quote so just start single quote and after newfilename single quote
-    sprintf( newstr, "%s'%s'", tstr1, newstr2 );
+    newstr = tstr1;
+    newstr += "'";
+    newstr += newstr2;
+    newstr += "'";
     break;
   }
   _freesafe( newstr2 );
   _freesafe( tstr1 );
-  return newstr;
+  return dupstring( newstr.c_str() );
 }
 
 /* this function replace all single quotes with '\'' so it can be
