@@ -1,6 +1,6 @@
 /* message.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,8 @@
 #include <X11/Xlib.h>
 #include <list>
 #include <string>
+#include <vector>
+#include <tuple>
 
 class Button;
 class ChooseButton;
@@ -85,7 +87,9 @@ enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_M
       AG_SLIDER_PRESSED, AG_SLIDER_CHANGED,
       AG_POPUPMENU_CLICKED, AG_POPUPMENU_CLOSED, AG_POPUPMENU_ENTRYEDITED,
       AG_TEXTVIEW_END_REACHED,
-      AG_CLIENT_MESSAGE
+      AG_CLIENT_MESSAGE,
+
+      AG_PASTE_FILE_LIST
 };
 
 typedef struct agkey {
@@ -255,6 +259,12 @@ typedef struct {
     ag_client_message_t cm_type;
 } AGClientMessage;
 
+typedef struct {
+    int type;
+    void *agmessage_data;
+    std::tuple< int, std::string, std::vector< std::string > > *file_list;
+} AGPaste;
+
 typedef union agmessage {
   int type;
   AGKey key;
@@ -274,6 +284,7 @@ typedef union agmessage {
   AGPopUpMenu popupmenu;
   AGTextView textview;
   AGClientMessage clientmessage;
+    AGPaste paste;
   long direct[20];
 } AGMessage;
 
