@@ -1,6 +1,6 @@
 /* popupmenu.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2021 Ralf Hoffmann.
+ * Copyright (C) 2007-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -159,6 +159,10 @@ void PopUpMenu::show( int x, int y, popup_show_t show_type )
                                               CurrentTime );
         }
         m_ignore_button_release = true;
+
+        if ( m_focus_out_ignore_time_ms > 0 ) {
+            m_show_time_ms = AGUIXUtils::current_time_ms();
+        }
     }
 }
 
@@ -557,8 +561,16 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
               }
               ret_val = true;
               break;
-          case UnmapNotify:
           case FocusOut:
+              if ( m_focus_out_ignore_time_ms > 0 ) {
+                  uint64_t now = AGUIXUtils::current_time_ms();
+                  if ( now - m_show_time_ms < m_focus_out_ignore_time_ms ) {
+                      // take back focus during grace period
+                      setXFocus();
+                  }
+                  break;
+              }
+          case UnmapNotify:
               hide();
               break;
           default:
@@ -1105,3 +1117,8 @@ void PopUpMenu::setHelpCB( std::function< void( const std::string &help ) > help
 {
     m_help_cb = help_cb;
 }
+
+void PopUpMenu::setFocusOutIgnoreTime( uint64_t ms )
+{
+    m_focus_out_ignore_time_ms = ms;
+}
