@@ -337,23 +337,43 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                 if(forbidPosChange==false) {
                     _aguix->queryPointer(msg->window,&tx,&ty);
 
-                    int bw = getBorderWidth();
-                    tx -= bw;
-                    ty -= bw;
+                    if ( m_click_mode == AGUIX::NO_CLICK ) {
+                        m_last_click_time = msg->time;
+                        m_click_mode = AGUIX::NORMAL_CLICK;
 
-                    int l, strwidth;
-                    l = _aguix->getStrlen4Width( content.getText() + content.getXOffset(), a_max( tx - 2, 0 ), &strwidth, font );
-	  
-                    int new_cursorpos = l + content.getXOffset();
-                    if ( new_cursorpos >= (int)strlen( content.getText() ) ) new_cursorpos = (int)strlen( content.getText() );
-                    if ( new_cursorpos < 0 ) new_cursorpos = 0;
-                    content.setCursorPos( new_cursorpos );
-                    content.setSelStart( new_cursorpos );
-                    content.setSelEnd( new_cursorpos );
-                    if ( ! m_read_only && msg->button == Button2 ) {
-                        insertSelection();
+                        updateSelection( tx, ty, true );
+                    } else if ( m_click_mode == AGUIX::NORMAL_CLICK ) {
+                        if ( _aguix->isDoubleClick( msg->time, m_last_click_time ) &&
+                             isNearFirstClick( tx, ty ) ) {
+                            m_last_click_time = msg->time;
+                            m_click_mode = AGUIX::DOUBLE_CLICK;
+
+                            updateSelection( tx, ty, false );
+                        } else {
+                            m_last_click_time = msg->time;
+                            m_click_mode = AGUIX::NORMAL_CLICK;
+
+                            updateSelection( tx, ty, true );
+                        }
+                    } else if ( m_click_mode == AGUIX::DOUBLE_CLICK ) {
+                        if ( _aguix->isDoubleClick( msg->time, m_last_click_time ) &&
+                             isNearFirstClick( tx, ty ) ) {
+                            m_last_click_time = msg->time;
+                            m_click_mode = AGUIX::TRIPLE_CLICK;
+
+                            updateSelection( tx, ty, false );
+                        } else {
+                            m_last_click_time = msg->time;
+                            m_click_mode = AGUIX::NORMAL_CLICK;
+
+                            updateSelection( tx, ty, true );
+                        }
+                    } else {
+                        m_last_click_time = msg->time;
+                        m_click_mode = AGUIX::NORMAL_CLICK;
+
+                        updateSelection( tx, ty, true );
                     }
-                    redraw();
                 }
             }
         } else {
@@ -682,43 +702,16 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
                     }
                 }
             } else if(msg->type==ButtonRelease) {
-                applySelection();
+                if ( ! m_read_only && msg->button == Button2 ) {
+                    insertSelection();
+                    redraw();
+                }
             } else if ( msg->type == MotionNotify &&
                         msg->window == win &&
                         ( msg->keystate & Button1Mask ) == Button1Mask ) {
                 _aguix->queryPointer(msg->window,&tx,&ty);
 
-                int bw = getBorderWidth();
-                tx -= bw;
-                ty -= bw;
-
-                if ( ( tx < 0 ) && ( content.getXOffset() > 0 ) ){
-                    int val = content.getXOffset();
-                    UTF8::movePosToPrevChar( content.getText(), val );
-                    content.setXOffset( val );
-                    content.setCursorPos( val );
-                } else if ( tx >= getInnerWidth() ) {
-                    int l, strwidth;
-                    l = _aguix->getStrlen4Width( content.getText() + content.getXOffset(), a_min( tx , getInnerWidth() ) - 2, &strwidth, font );
-
-                    content.setCursorPos( l + content.getXOffset() );
-                    if ( content.getCursorPos() < (int)strlen( content.getText() ) ) {
-                        int val = content.getXOffset();
-                        UTF8::movePosToNextChar( content.getText(), val );
-                        content.setXOffset( val );
-                    }
-                } else {
-                    int l, strwidth;
-                    l = _aguix->getStrlen4Width( content.getText() + content.getXOffset(), tx - 2, &strwidth, font );
-
-                    int ncp = l + content.getXOffset();
-                    if(ncp>=(int)strlen(content.getText())) ncp=strlen(content.getText());
-                    if(ncp<0) ncp=0;
-                    content.setCursorPos( ncp );
-                }
-
-                content.setSelEnd( content.getCursorPos() );
-                redraw();
+                updateSelection( tx, ty, false );
             }
         }
     } else if(msg->type==ButtonPress) {
@@ -733,18 +726,10 @@ bool StringGadget::handleMessage(XEvent *E,Message *msg)
             if(forbidPosChange==false) {
                 _aguix->queryPointer(msg->window,&tx,&ty);
 
-                int bw = getBorderWidth();
-                tx -= bw;
-                ty -= bw;
+                m_last_click_time = msg->time;
+                m_click_mode = AGUIX::NORMAL_CLICK;
 
-                int l, strwidth;
-                l = _aguix->getStrlen4Width( content.getText() + content.getXOffset(), a_max( tx - 2, 0 ), &strwidth, font );
-                content.setCursorPos( l + content.getXOffset() );
-                if(content.getCursorPos()>=(int)strlen(content.getText())) content.setCursorPos( (int)strlen(content.getText()) );
-                if(content.getCursorPos()<0) content.setCursorPos( 0 );
-                content.setSelStart( content.getCursorPos() );
-                content.setSelEnd( content.getCursorPos() );
-                if(msg->button==Button2) insertSelection();
+                updateSelection( tx, ty, true );
             }
             redraw();
         }
@@ -1420,3 +1405,127 @@ void StringGadget::setReadOnly( bool nv )
 {
     m_read_only = nv;
 }
+
+bool StringGadget::isNearFirstClick( int mx, int my ) const
+{
+    if ( labs( mx - m_first_click_pos.mx ) < 5 ) {
+        return true;
+    }
+    return false;
+}
+
+void StringGadget::updateSelection( int mx, int my, bool initial )
+{
+    int bw = getBorderWidth();
+    mx -= bw;
+    my -= bw;
+
+    if ( initial ) {
+        m_first_click_pos = { mx, content.getXOffset() };
+        auto first = getSelectionElement( m_first_click_pos.mx, m_first_click_pos.xoffset );
+        content.setCursorPos( first.second );
+        content.setSelStart( first.first );
+        content.setSelEnd( first.second );
+        redraw();
+        return;
+    }
+
+    if ( m_click_mode == AGUIX::NO_CLICK ) return;
+
+    auto first = getSelectionElement( m_first_click_pos.mx, m_first_click_pos.xoffset );
+    auto second = getSelectionElement( mx, content.getXOffset() );
+
+    if ( first.first < second.first ||
+         ( first.first == second.first &&
+           first.second < second.second ) ) {
+        content.setCursorPos( second.second );
+        content.setSelStart( first.first );
+        content.setSelEnd( second.second );
+    } else {
+        content.setCursorPos( first.second );
+        content.setSelStart( second.first );
+        content.setSelEnd( first.second );
+    }
+
+    applySelection();
+
+    if ( mx < 0 && content.getXOffset() > 0 ) {
+        int val = content.getXOffset();
+        UTF8::movePosToPrevChar( content.getText(), val );
+        content.setXOffset( val );
+    } else if ( mx >= getInnerWidth() ) {
+        int l, strwidth;
+        l = _aguix->getStrlen4Width( content.getText() + content.getXOffset(), getInnerWidth() - 2, &strwidth, font );
+
+        if ( l + content.getXOffset() < content.getCursorPos() ) {
+            int val = content.getXOffset();
+            UTF8::movePosToNextChar( content.getText(), val );
+            content.setXOffset( val );
+        }
+    }
+
+    redraw();
+}
+
+std::pair< int, int > StringGadget::getSelectionElement( const int mx,
+                                                         const int xoffset ) const
+{
+    int l, strwidth;
+    const char *str = content.getText();
+    int str_len = (int)strlen( str );
+    
+    l = _aguix->getStrlen4Width( str + xoffset, a_max( mx - 2, 0 ), &strwidth, font );
+	  
+    int cursorpos = l + xoffset;
+    if ( cursorpos > str_len ) cursorpos = str_len;
+    if ( cursorpos < 0 ) cursorpos = 0;
+
+    if ( m_click_mode == AGUIX::NORMAL_CLICK ) {
+        return { cursorpos, cursorpos };
+    }
+
+    if ( m_click_mode == AGUIX::TRIPLE_CLICK ) {
+        return { 0, strlen( str ) };
+    }
+
+    int start_pos = cursorpos;
+    int end_pos = cursorpos;
+    int word_start = start_pos;
+    int word_end = end_pos;
+
+    for (;;) {
+        if ( std::isspace( str[ start_pos ] ) ||
+             str[ start_pos ] == '/' ) {
+            break;
+        }
+
+        word_start = start_pos;
+
+        UTF8::movePosToPrevChar( str, start_pos );
+
+        if ( word_start == start_pos ) {
+            break;
+        }
+    }
+
+    for (;;) {
+        if ( std::isspace( str[ end_pos ] ) ||
+             str[ end_pos ] == '/' ) {
+            break;
+        }
+
+        word_end = end_pos;
+
+        if ( end_pos >= str_len) {
+            break;
+        }
+
+        UTF8::movePosToNextChar( str, end_pos );
+
+        if ( word_end == end_pos ) {
+            break;
+        }
+    }
+
+    return { word_start, word_end };
+}
