@@ -23,6 +23,7 @@
 #define STRINGGADGET_H
 
 #include "aguixdefs.h"
+#include "aguix.h"
 #include "guielement.h"
 #include <string>
 #include <vector>
@@ -115,7 +116,14 @@ private:
   bool ignoreRelease;
   bool strongkeycapture;
   bool m_read_only;
-  
+
+    AGUIX::mouse_click_mode m_click_mode = AGUIX::NO_CLICK;
+    Time m_last_click_time = {0};
+    struct {
+        int mx;
+        int xoffset;
+    } m_first_click_pos = { 0, 0 };
+
   void updateWin();
   void textRedraw();
   void applySelection( bool both_buffers = false );
@@ -137,6 +145,11 @@ private:
 
   void jumpToNextWord();
   void jumpToPrevWord();
+
+    void updateSelection( int mx, int my, bool initial );
+    bool isNearFirstClick( int mx, int my ) const;
+    std::pair< int, int > getSelectionElement( const int mx,
+                                               const int xoffset ) const;
 };
 
 #endif
