@@ -1,6 +1,6 @@
 /* text.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2024 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,7 +26,8 @@
 
 const char *Text::type="Text";
 
-Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext ) : GUIElement( taguix )
+Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, enum center_mode center_mode )
+    : GUIElement( taguix )
 {
   this->text=dupstring(ttext);
   _x=tx;
@@ -40,9 +41,12 @@ Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext ) : GUIElement( tag
   ownbg = false;
 
   m_shrinker_buf.current_width = -1;
+
+  m_center_mode = center_mode;
 }
 
-Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, int tfg, int tbg ):GUIElement( taguix )
+Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, int tfg, int tbg, enum center_mode center_mode )
+    : GUIElement( taguix )
 {
   this->text = dupstring( ttext );
   _x = tx;
@@ -56,6 +60,8 @@ Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext, int tfg, int tbg )
   ownbg = true;
 
   m_shrinker_buf.current_width = -1;
+
+  m_center_mode = center_mode;
 }
 
 Text::~Text()
@@ -113,6 +119,20 @@ void Text::redraw()
 
     DrawableCont dc( _aguix, win );
 
+    int y = 0;
+
+    if ( m_center_mode & CENTER_VERTICALLY ) {
+        int th;
+        
+        if ( font ) {
+            th = font->getCharHeight();
+        } else {
+            th = _aguix->getCharHeight();
+        }
+
+        y = getHeight() / 2 - th / 2;
+    }
+
     if ( m_shrinker.get() != NULL ) {
         if ( m_shrinker_buf.current_width != getWidth() ) {
             AFontWidth len_calc( _aguix, font );
@@ -120,9 +140,9 @@ void Text::redraw()
             m_shrinker_buf.current_text = m_shrinker->shrink( text, getWidth(), len_calc );
             m_shrinker_buf.current_width = getWidth();
         }
-        _aguix->DrawText( dc, font, m_shrinker_buf.current_text.c_str(), 0, 0, color );
+        _aguix->DrawText( dc, font, m_shrinker_buf.current_text.c_str(), 0, y, color );
     } else {
-        _aguix->DrawText( dc, font, text, 0, 0, color );
+        _aguix->DrawText( dc, font, text, 0, y, color );
     }
   }
 }
