@@ -56,8 +56,7 @@ TextView::TextView( AGUIX *parent,
     tvcb( this ),
     _show_line_numbers( false ),
     m_buffer( 0 ),
-    m_show_frame( true ),
-    m_last_mouse_time( 0 )
+    m_show_frame( true )
 {
   hbar = vbar = NULL;
   cont = NULL;
@@ -231,7 +230,7 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
 
       _aguix->queryPointer( win, &mx, &my );
 
-      updateSelection( mx, my );
+      updateSelection( mx, my, false );
   } else if ( ( msg->type == ButtonPress ) && ( msg->window == win ) ) {
     if ( ( msg->button == Button4 ) || ( msg->button == Button5 ) ) {
       gettimeofday( &t2, NULL );
@@ -267,12 +266,51 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
 
       redraw();
 
-      m_button_press_unwrapped_line_pos = getTextPosForMousePos( msg->mousex, msg->mousey );
-
       m_selection_scroll_active = true;
       _aguix->Flush();
       _aguix->msgLock( this );
       _aguix->enableTimer();
+
+      int mx, my;
+      _aguix->queryPointer( win, &mx, &my );
+
+      if ( m_click_mode == AGUIX::NO_CLICK ) {
+          m_last_click_time = msg->time;
+          m_click_mode = AGUIX::NORMAL_CLICK;
+
+          updateSelection( mx, my, true );
+      } else if ( m_click_mode == AGUIX::NORMAL_CLICK ) {
+          if ( _aguix->isDoubleClick( msg->time, m_last_click_time ) &&
+               isNearFirstClick( mx, my ) ) {
+              m_last_click_time = msg->time;
+              m_click_mode = AGUIX::DOUBLE_CLICK;
+
+              updateSelection( mx, my, false );
+          } else {
+              m_last_click_time = msg->time;
+              m_click_mode = AGUIX::NORMAL_CLICK;
+
+              updateSelection( mx, my, true );
+          }
+      } else if ( m_click_mode == AGUIX::DOUBLE_CLICK ) {
+          if ( _aguix->isDoubleClick( msg->time, m_last_click_time ) &&
+               isNearFirstClick( mx, my ) ) {
+              m_last_click_time = msg->time;
+              m_click_mode = AGUIX::TRIPLE_CLICK;
+
+              updateSelection( mx, my, false );
+          } else {
+              m_last_click_time = msg->time;
+              m_click_mode = AGUIX::NORMAL_CLICK;
+
+              updateSelection( mx, my, true );
+          }
+      } else {
+          m_last_click_time = msg->time;
+          m_click_mode = AGUIX::NORMAL_CLICK;
+
+          updateSelection( mx, my, true );
+      }
     } else if ( msg->button == s_scroll_button ) {
         handleThird( msg );
     }
@@ -286,18 +324,6 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
               _aguix->msgUnlock( this );
               m_selection_scroll_active = false;
           }
-
-          if ( _aguix->isDoubleClick( msg->time, m_last_mouse_time ) ) {
-              int mx, my;
-
-              _aguix->queryPointer( win, &mx, &my );
-
-              handleDoubleClick( mx, my );
-
-              m_last_mouse_time = 0;
-          } else {
-              m_last_mouse_time = msg->time;
-          }
       }
   } else if ( msg->type == ClientMessage ) {
       if ( msg->specialType == Message::TIMEREVENT &&
@@ -327,7 +353,7 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
           }
 
           if ( scrollView( xdelta, ydelta ) != 0 ) {
-              updateSelection( mx, my );
+              updateSelection( mx, my, false );
           }
       }
   }
@@ -1465,60 +1491,6 @@ void TextView::showFrame( bool nv )
     m_show_frame = nv;
 }
 
-void TextView::handleDoubleClick( int mx, int my )
-{
-    std::pair< int, int > cur = getTextPosForMousePos( mx, my );
-    std::string line_str;
-
-    if ( m_ts->getUnwrappedLine( cur.first, 0, -1, line_str ) != 0 ) {
-        return;
-    }
-
-    int start_pos = cur.second;
-    int end_pos = cur.second;
-    int word_start = start_pos;
-    int word_end = end_pos;
-
-    if ( start_pos < 0 || start_pos >= (int)line_str.size() ) return;
-    if ( end_pos < 0 || end_pos >= (int)line_str.size() ) return;
-    
-    for (;;) {
-        if ( std::isspace( line_str[ start_pos ] ) ) {
-            break;
-        }
-
-        word_start = start_pos;
-
-        UTF8::movePosToPrevChar( line_str.c_str(), start_pos );
-
-        if ( word_start == start_pos ) {
-            break;
-        }
-    }
-
-    for (;;) {
-        word_end = end_pos;
-
-        if ( end_pos >= (int)line_str.size() ) {
-            break;
-        }
-        if ( std::isspace( line_str[ end_pos ] ) ) {
-            break;
-        }
-
-        UTF8::movePosToNextChar( line_str.c_str(), end_pos );
-
-        if ( word_end == end_pos ) {
-            break;
-        }
-    }
-
-    setSelectionStart( cur.first, word_start );
-    setSelectionEnd( cur.first, word_end );
-    copySelectionToClipboard();
-    redraw();
-}
-
 int TextView::scrollView( int xdelta, int ydelta )
 {
     int res = 0;
@@ -1545,7 +1517,7 @@ int TextView::scrollView( int xdelta, int ydelta )
     return res;
 }
 
-void TextView::updateSelection( int mx, int my )
+void TextView::updateSelection( int mx, int my, bool initial )
 {
     int x, y, w, h;
 
@@ -1560,29 +1532,32 @@ void TextView::updateSelection( int mx, int my )
 
     std::pair< int, int > cur = getTextPosForMousePos( mx, my );
 
-    if ( cur != m_button_press_unwrapped_line_pos ) {
-        int cur_sel = - 1, cur_off = -1;
-
-        getSelectionEnd( cur_sel, cur_off );
-
-        if ( cur_sel != cur.first || cur_off != cur.second ) {
-            if ( m_button_press_unwrapped_line_pos.first < cur.first ||
-                 ( m_button_press_unwrapped_line_pos.first == cur.first &&
-                   m_button_press_unwrapped_line_pos.second < cur.second ) ) {
-                setSelectionStart( m_button_press_unwrapped_line_pos.first,
-                                   m_button_press_unwrapped_line_pos.second );
-                setSelectionEnd( cur.first,
-                                 cur.second );
-            } else {
-                setSelectionStart( cur.first,
-                                   cur.second );
-                setSelectionEnd( m_button_press_unwrapped_line_pos.first,
-                                 m_button_press_unwrapped_line_pos.second );
-            }
-
-            redraw();
-        }
+    if ( initial ) {
+        m_first_click_text_pos = cur;
+        m_first_click_pos = { mx, my };
+        return;
     }
+
+    if ( m_click_mode == AGUIX::NO_CLICK ) return;
+
+    auto first = getSelectionElement( m_first_click_text_pos );
+    auto second = getSelectionElement( cur );
+
+    if ( first.first.first < second.first.first ||
+         ( first.first.first == second.first.first &&
+           first.first.second < second.first.second ) ) {
+        setSelectionStart( first.first.first,
+                           first.first.second );
+        setSelectionEnd( second.second.first,
+                         second.second.second );
+    } else {
+        setSelectionStart( second.first.first,
+                           second.first.second );
+        setSelectionEnd( first.second.first,
+                         first.second.second );
+    }
+
+    redraw();
 }
 
 void TextView::getTextArea( int &x, int &y,
@@ -1619,3 +1594,81 @@ void TextView::scrollToEnd()
 		redraw();
     }
 }
+
+std::pair< std::pair< int, int >,
+           std::pair< int, int > > TextView::getSelectionElement( const std::pair< int, int > &pos )
+{
+    if ( m_click_mode == AGUIX::NORMAL_CLICK ) {
+        return { pos, pos };
+    }
+
+    if ( m_click_mode == AGUIX::TRIPLE_CLICK ) {
+        if ( pos.first + 1 == m_ts->getNrOfUnwrappedLines() ) {
+            std::string line_str;
+
+            if ( m_ts->getUnwrappedLine( pos.first, 0, -1, line_str ) != 0 ) {
+                return { pos, pos };
+            } else {
+                return { { pos.first, 0 }, { pos.first, line_str.size() } };
+            }
+        } else {
+            return { { pos.first, 0 }, { pos.first + 1, 0 } };
+        }
+    }
+
+    std::string line_str;
+
+    if ( m_ts->getUnwrappedLine( pos.first, 0, -1, line_str ) != 0 ) {
+        return { pos, pos };
+    }
+
+    int start_pos = pos.second;
+    int end_pos = pos.second;
+    int word_start = start_pos;
+    int word_end = end_pos;
+
+    if ( start_pos < 0 || start_pos >= (int)line_str.size() ) return { pos, pos };
+    if ( end_pos < 0 || end_pos >= (int)line_str.size() ) return { pos, pos };
+    
+    for (;;) {
+        if ( std::isspace( line_str[ start_pos ] ) ) {
+            break;
+        }
+
+        word_start = start_pos;
+
+        UTF8::movePosToPrevChar( line_str.c_str(), start_pos );
+
+        if ( word_start == start_pos ) {
+            break;
+        }
+    }
+
+    for (;;) {
+        word_end = end_pos;
+
+        if ( end_pos >= (int)line_str.size() ) {
+            break;
+        }
+        if ( std::isspace( line_str[ end_pos ] ) ) {
+            break;
+        }
+
+        UTF8::movePosToNextChar( line_str.c_str(), end_pos );
+
+        if ( word_end == end_pos ) {
+            break;
+        }
+    }
+
+    return { { pos.first, word_start }, { pos.first, word_end } };
+}
+
+bool TextView::isNearFirstClick( int mx, int my ) const
+{
+    if ( labs( mx - m_first_click_pos.x ) < 5 &&
+         labs( my - m_first_click_pos.y ) < 5 ) {
+        return true;
+    }
+    return false;
+}
