@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -694,4 +694,16 @@ namespace AGUIXUtils
 
         return res;
     }
+
+    uint64_t current_time_ms()
+    {
+        struct timespec ts;
+
+        if ( clock_gettime( CLOCK_MONOTONIC, &ts ) != 0 ) return 0;
+
+        uint64_t res = ts.tv_sec * 1000;
+        res += ts.tv_nsec / 1000000;
+
+        return res;
+    }
 }
