@@ -27,6 +27,7 @@
 #include <sstream>
 #include <stdexcept>
 #include <vector>
+#include <cinttypes>
 
 int createLines( const char*, char ***, const char split = '|' );
 
@@ -144,6 +145,8 @@ namespace AGUIXUtils
     std::string replace_percent_s_quoted( const std::string &src,
                                           const std::string &replacement,
                                           std::string *return_suffix );
+
+    uint64_t current_time_ms();
 }
 
 #define TIMEMEASURE_T struct timeval
