@@ -133,7 +133,7 @@ BookmarkDBProxy::check_path_res_t BookmarkDBProxy::checkPath( const std::string
         for ( it2 = node_datas.begin();
               it2 != node_datas.end();
               it2++ ) {
-            if ( it2->getVal() != NULL ) {
+            if ( it2->get() != NULL ) {
                 return_entries.push_back( **it2 );
             }
         }
