@@ -23,9 +23,9 @@
 #include <string>
 #include <sstream>
 #include <iomanip>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/stringgadget.h>
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/stringgadget.h"
 #include "worker.h"
 #include "worker_locale.h"
 
