@@ -1,6 +1,6 @@
 /* changecolumnsop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2015-2021 Ralf Hoffmann.
+ * Copyright (C) 2015-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -142,6 +142,9 @@ ChangeColumnsOp::save( Datei *fh )
             case WorkerTypes::LISTCOL_EXTENSION:
                 fh->configPutInfo( "extension", true );
                 break;
+            case WorkerTypes::LISTCOL_CUSTOM_ATTR:
+                fh->configPutInfo( "customattribute", true );
+                break;
             default:
                 fh->configPutInfo( "name", true );
                 break;
@@ -188,7 +191,7 @@ ChangeColumnsOp::configure()
     ac0->setBorderWidth( 5 );
 
     RefCount<AFontWidth> lencalc( new AFontWidth( aguix, NULL ) );
-    TextStorageString help_ts( catalog.getLocale( 1120 ), lencalc );
+    auto help_ts = std::make_shared< TextStorageString >( catalog.getLocale( 1120 ), lencalc );
     TextView *help_tv = (TextView*)ac0->add( new TextView( aguix,
                                                            0, 0, 400, 50, "", help_ts ),
                                              0, 0, AContainer::CO_INCW );
