@@ -1,6 +1,6 @@
 /* changesymlinkop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,16 +33,15 @@ public:
   ChangeSymlinkOp( const ChangeSymlinkOp &other );
   ChangeSymlinkOp &operator=( const ChangeSymlinkOp &other );
 
-  virtual ChangeSymlinkOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
+  ChangeSymlinkOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
 
-  using FunctionProto::run;
-  int run( WPUContext *wpu, ActionMessage* );
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
 
-  const char *getDescription();
-  int configure();
-  bool save(Datei*);
+  const char *getDescription() override;
+  int configure() override;
+  bool save(Datei*) override;
 
   typedef enum { CHANGESYMLINK_EDIT,
                  CHANGESYMLINK_MAKE_ABSOLUTE,
