@@ -447,7 +447,7 @@ static void setOctalSGForMode( StringGadget *octal_sg, mode_t permissions )
 
 static mode_t getModeFromOctalSG( StringGadget *octal_sg )
 {
-    int mode;
+    unsigned int mode;
 
     if ( sscanf( octal_sg->getText(), "%o", &mode ) == 1 ) {
         return (mode_t)mode;
