@@ -23,7 +23,7 @@
 #define CONDPARSER_H
 
 #include "wdefines.h"
-#include <aguix/compregex.hh>
+#include "aguix/compregex.hh"
 
 class FileEntry;
 
