@@ -492,7 +492,13 @@ struct mytoken tokenlist[]={
   { APPLYONLY_WCP, "applyonly" },
   { USESELECTEDENTRIES_WCP, "useselectedentries" },
   { ONLYEXACTPATH_WCP, "onlyexactpath" },
-  { ALSOSELECTEXTENSION_WCP, "alsoselectextension" }
+  { ALSOSELECTEXTENSION_WCP, "alsoselectextension" },
+  { CUSTOMWITHHINT_WCP, "customwithhint" },
+  { DIFFERENTSIZE_WCP, "differentsize" },
+  { SMALLER_WCP, "smaller" },
+  { OLDER_WCP, "older" },
+  { KVPENTRIES_WCP, "kvpentries" },
+  { KVPENTRY_WCP, "kvpentry" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
