@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2022 Ralf Hoffmann.
+ * Copyright (C) 2001-2025 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,7 +30,6 @@
 #include "aguix/choosebutton.h"
 #include "aguix/cyclebutton.h"
 #include "aguix/button.h"
-#include "copyorder.hh"
 #include "virtualdirmode.hh"
 
 using namespace CopyParams;
@@ -44,7 +43,6 @@ CopyOp::CopyOp() : FunctionProto()
   do_rename=false;
   same_dir=false;
   request_dest=false;
-  overwrite=COPYOP_OVERWRITE_NORMAL;
   preserve_attr=true;
   vdir_preserve_dir_structure = false;
   adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_NEVER;
@@ -123,12 +121,21 @@ CopyOp::save(Datei *fh)
   fh->configPutPairBool( "requestdest", request_dest );
   fh->configPutPairBool( "requestflags", requestParameters() );
   switch(overwrite) {
-    case COPYOP_OVERWRITE_ALWAYS:
+    case copyorder::COPY_OVERWRITE_ALWAYS:
       fh->configPutPair( "overwrite", "always" );
       break;
-    case COPYOP_OVERWRITE_NEVER:
+    case copyorder::COPY_OVERWRITE_NEVER:
       fh->configPutPair( "overwrite", "never" );
       break;
+    case copyorder::COPY_OVERWRITE_OLDER:
+      fh->configPutPair( "overwrite", "older" );
+      break;
+    case copyorder::COPY_OVERWRITE_SMALLER:
+      fh->configPutPair( "overwrite", "smaller" );
+      break;
+    case copyorder::COPY_OVERWRITE_DIFFERENT_SIZE:
+      fh->configPutPair( "overwrite", "differentsize" );
+      break;
     default:
       fh->configPutPair( "overwrite", "normal" );
       break;
@@ -210,17 +217,26 @@ CopyOp::normalmodecopy( ActionMessage *am )
     tadjust_relative_symlinks = adjust_relative_symlinks;
     tensure_file_permissions = ensure_file_permissions;
 
-    if ( toverwrite != COPYOP_OVERWRITE_NORMAL ) {
+    if ( toverwrite != copyorder::COPY_OVERWRITE_NORMAL ) {
         std::string textstr;
 
         switch ( toverwrite ) {
-            case COPYOP_OVERWRITE_ALWAYS:
+            case copyorder::COPY_OVERWRITE_ALWAYS:
                 textstr = catalog.getLocale( 1439 );
                 break;
-            case COPYOP_OVERWRITE_NEVER:
+            case copyorder::COPY_OVERWRITE_NEVER:
                 textstr = catalog.getLocale( 1440 );
                 break;
-            case COPYOP_OVERWRITE_NORMAL:
+            case copyorder::COPY_OVERWRITE_OLDER:
+                textstr = catalog.getLocale( 1586 );
+                break;
+            case copyorder::COPY_OVERWRITE_SMALLER:
+                textstr = catalog.getLocale( 1587 );
+                break;
+            case copyorder::COPY_OVERWRITE_DIFFERENT_SIZE:
+                textstr = catalog.getLocale( 1588 );
+                break;
+            case copyorder::COPY_OVERWRITE_NORMAL:
                 // will not happen, but to make compiler happy
                 abort();
                 break;
@@ -408,16 +424,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
         co->ensure_file_permissions = tensure_file_permissions;
 
         co->do_rename=trename;
-        switch(toverwrite) {
-            case COPYOP_OVERWRITE_ALWAYS:
-                co->overwrite=co->COPY_OVERWRITE_ALWAYS;
-                break;
-            case COPYOP_OVERWRITE_NEVER:
-                co->overwrite=co->COPY_OVERWRITE_NEVER;
-                break;
-            default:
-                co->overwrite=co->COPY_OVERWRITE_NORMAL;
-        }
+        co->overwrite = toverwrite;
         co->destdir = destination_directory.c_str();
         // now start copy process
         co->cowin=new CopyOpWin( am->getWorker()->getAGUIX(),
@@ -583,17 +590,29 @@ CopyOp::doconfigure(int mode)
   overwritemode_cyb->addOption( catalog.getLocale( 304 ) );
   overwritemode_cyb->addOption( catalog.getLocale( 305 ) );
   overwritemode_cyb->addOption( catalog.getLocale( 306 ) );
+  overwritemode_cyb->addOption( catalog.getLocale( 1589 ) );
+  overwritemode_cyb->addOption( catalog.getLocale( 1590 ) );
+  overwritemode_cyb->addOption( catalog.getLocale( 1591 ) );
   overwritemode_cyb->resize( overwritemode_cyb->getMaxSize(),
                              overwritemode_cyb->getHeight() );
   ac1_overwrite_mode->readLimits();
 
   switch ( overwrite ) {
-      case COPYOP_OVERWRITE_ALWAYS:
+      case copyorder::COPY_OVERWRITE_ALWAYS:
           overwritemode_cyb->setOption( 1 );
           break;
-      case COPYOP_OVERWRITE_NEVER:
+      case copyorder::COPY_OVERWRITE_NEVER:
           overwritemode_cyb->setOption( 2 );
           break;
+      case copyorder::COPY_OVERWRITE_OLDER:
+          overwritemode_cyb->setOption( 3 );
+          break;
+      case copyorder::COPY_OVERWRITE_SMALLER:
+          overwritemode_cyb->setOption( 4 );
+          break;
+      case copyorder::COPY_OVERWRITE_DIFFERENT_SIZE:
+          overwritemode_cyb->setOption( 5 );
+          break;
       default:
           overwritemode_cyb->setOption( 0 );
           break;
@@ -723,16 +742,25 @@ CopyOp::doconfigure(int mode)
               break;
       }
 
-      toverwrite=COPYOP_OVERWRITE_NORMAL;
+      toverwrite=copyorder::COPY_OVERWRITE_NORMAL;
       switch ( overwritemode_cyb->getSelectedOption() ) {
           case 1:
-              toverwrite = COPYOP_OVERWRITE_ALWAYS;
+              toverwrite = copyorder::COPY_OVERWRITE_ALWAYS;
               break;
           case 2:
-              toverwrite = COPYOP_OVERWRITE_NEVER;
+              toverwrite = copyorder::COPY_OVERWRITE_NEVER;
+              break;
+          case 3:
+              toverwrite = copyorder::COPY_OVERWRITE_OLDER;
+              break;
+          case 4:
+              toverwrite = copyorder::COPY_OVERWRITE_SMALLER;
+              break;
+          case 5:
+              toverwrite = copyorder::COPY_OVERWRITE_DIFFERENT_SIZE;
               break;
           default:
-              toverwrite = COPYOP_OVERWRITE_NORMAL;
+              toverwrite = copyorder::COPY_OVERWRITE_NORMAL;
               break;
       }
     } else {
@@ -773,16 +801,25 @@ CopyOp::doconfigure(int mode)
               break;
       }
 
-      overwrite=COPYOP_OVERWRITE_NORMAL;
+      overwrite=copyorder::COPY_OVERWRITE_NORMAL;
       switch ( overwritemode_cyb->getSelectedOption() ) {
           case 1:
-              overwrite = COPYOP_OVERWRITE_ALWAYS;
+              overwrite = copyorder::COPY_OVERWRITE_ALWAYS;
               break;
           case 2:
-              overwrite = COPYOP_OVERWRITE_NEVER;
+              overwrite = copyorder::COPY_OVERWRITE_NEVER;
+              break;
+          case 3:
+              overwrite = copyorder::COPY_OVERWRITE_OLDER;
+              break;
+          case 4:
+              overwrite = copyorder::COPY_OVERWRITE_SMALLER;
+              break;
+          case 5:
+              overwrite = copyorder::COPY_OVERWRITE_DIFFERENT_SIZE;
               break;
           default:
-              overwrite = COPYOP_OVERWRITE_NORMAL;
+              overwrite = copyorder::COPY_OVERWRITE_NORMAL;
               break;
       }
     }
@@ -867,7 +904,7 @@ void CopyOp::setRequestDest(bool nv)
   request_dest=nv;
 }
 
-void CopyOp::setOverwrite(overwrite_t nv)
+void CopyOp::setOverwrite(copyorder::overwrite_type nv)
 {
   overwrite=nv;
 }
