@@ -812,6 +812,18 @@ int CopyOpWin::request_int( const char *title,
   }
 }
 
+int CopyOpWin::request_int( const char *title,
+                            const char *text,
+                            const std::vector< std::vector< std::pair< std::string, int > > > &button_rows,
+                            Requester::request_flags_t flags )
+{
+    if ( window != NULL ) {
+        return window->request( title, text, button_rows, flags );
+    } else {
+        return Worker::getRequester()->request( title, text, button_rows, NULL, flags );
+    }
+}
+
 int CopyOpWin::string_request_int( const char *title,
                                    const char *lines,
                                    const char *default_str,
@@ -902,6 +914,24 @@ int CopyOpWin::request( const std::string &title,
     }
 }
 
+int CopyOpWin::request( const std::string &title,
+                        const std::string &text,
+                        const std::vector< std::vector< std::pair< std::string, int > > > &button_rows,
+                        Requester::request_flags_t flags )
+{
+    BGCopyRequestMessage msg( title, text, button_rows );
+
+    if ( std::this_thread::get_id() == m_master_thread_id ) {
+        process_request( msg );
+
+        return msg.getRes();
+    } else {
+        push_request( msg );
+
+        return wait_for_response().getRes();
+    }
+}
+
 int CopyOpWin::string_request( const std::string &title,
                                const std::string &lines,
                                const std::string &default_str,
@@ -934,6 +964,10 @@ void CopyOpWin::process_request( BGCopyRequestMessage &msg )
         msg.setRes( request_int( msg.getTitle().c_str(),
                                  msg.getText().c_str(),
                                  msg.getButtons().c_str() ) );
+    } else if ( msg.getType() == BGCopyRequestMessage::MULTILINE_BUTTON_REQUEST ) {
+        msg.setRes( request_int( msg.getTitle().c_str(),
+                                 msg.getText().c_str(),
+                                 msg.getButtonRows() ) );
     } else if ( msg.getType() == BGCopyRequestMessage::STRING_REQUEST ) {
         char *result_string = NULL;
         int res = string_request_int( msg.getTitle().c_str(),
