@@ -1028,6 +1028,11 @@ void Datei::configPutPairNum( const char *id, int num1, int num2 )
   putLine( str1.c_str() );
 }
 
+void Datei::configPutPairString( const char *id, const std::string &str, bool escape_newlines )
+{
+    configPutPairString( id, str.c_str(), escape_newlines );
+}
+
 void Datei::configPutPairString( const char *id, const char *str, bool escape_newlines )
 {
   std::string str1;
