@@ -54,7 +54,7 @@ static void push_leafs( const DeepPathNode &node,
     }
 }
 
-std::list< std::pair< std::string, time_t > > DeepPathStore::getPaths()
+std::list< std::pair< std::string, time_t > > DeepPathStore::getPaths() const
 {
     std::list< std::pair< std::string, time_t > > l;
 
@@ -64,8 +64,9 @@ std::list< std::pair< std::string, time_t > > DeepPathStore::getPaths()
 }
 
 static void walk_leafs( const DeepPathNode &node,
-                        std::function< void( const std::string &, time_t ) > cb,
-                        const std::string &prefix )
+                        std::function< void( const std::string &, size_t, time_t ) > cb,
+                        const std::string &prefix,
+                        size_t depth )
 {
     std::string new_prefix( prefix );
 
@@ -73,20 +74,20 @@ static void walk_leafs( const DeepPathNode &node,
 
     if ( node.get_children().empty() ) {
         if ( ! new_prefix.empty() ) {
-            cb( new_prefix, node.get_ts() );
+            cb( new_prefix, depth, node.get_ts() );
         }
     } else {
         for ( std::list< DeepPathNode >::const_iterator it1 = node.get_children().begin();
               it1 != node.get_children().end();
               it1++ ) {
-            walk_leafs( *it1, cb, new_prefix );
+            walk_leafs( *it1, cb, new_prefix, depth + 1 );
         }
     }
 }
 
-void DeepPathStore::walkPaths( std::function< void( const std::string &, time_t ) > cb )
+void DeepPathStore::walkPaths( std::function< void( const std::string &, size_t, time_t ) > cb )
 {
-    walk_leafs( m_root, cb, "" );
+    walk_leafs( m_root, cb, "", 0 );
 }
 
 void DeepPathStore::storePath( DeepPathNode &node,
