@@ -1,6 +1,6 @@
 /* deleteop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2024 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "wdefines.h"
 #include "functionproto.h"
 #include "aguix/request.h"
+#include "filenameshrinker.hh"
 
 class AGUIX;
 class AWindow;
@@ -117,6 +118,8 @@ protected:
   int filenamespace;
   bool ismessage;
   AFontWidth *lencalc;
+  struct timeval m_last_update_time = {};
+    FileNameShrinker m_fns;
 };
 
 #endif
