@@ -121,13 +121,13 @@ int DirBookmarkOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 
             std::list< RefCount< ArgClass > > args;
 
-            args.push_back( new StringArg( dir ) );
+            args.push_back( RefCount< ArgClass >( new StringArg( dir ) ) );
             lm1->runCommand( "enter_dir", args );
 
             args.clear();
 
             if ( ! highlight_entry.empty() ) {
-                args.push_back( new StringArg( highlight_entry ) );
+                args.push_back( RefCount< ArgClass >( new StringArg( highlight_entry ) ) );
                 lm1->runCommand( "activate_entry", args );
             }
         } catch ( int ) {
