@@ -1,6 +1,6 @@
 /* dirbookmarkssettings.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2008,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include <string>
 #include <list>
 #include "fileentry.hh"
+#include "nwcentryselectionstate.hh"
 
 DirBookmarksSettings::DirBookmarksSettings() : m_serial_nr( 0 )
 {
@@ -51,6 +52,79 @@ struct copy_category
     }
 };
 
+bool DirBookmarksSettings::checkEntry( BookmarkDBProxy &bookmarks,
+                                       FileEntry *fe, NWCEntrySelectionState *es )
+{
+    if ( fe == NULL && es == NULL ) return false;
+
+    std::list< BookmarkDBEntry > bookmark_entries;
+
+    NWC::FSEntry *fse = NULL;
+
+    if ( es ) {
+        fse = es->getNWCEntry();
+
+        if ( ! fse ) return false;
+    }
+
+    BookmarkDBProxy::check_path_res_t res = bookmarks.checkPath( fe ? fe->fullname : fse->getFullname(),
+                                                                 bookmark_entries );
+
+    std::list<std::string> matching_labels;
+    std::list<std::string>::iterator full_hit_it = matching_labels.end();
+
+    if ( bookmark_entries.empty() == true ) {
+        res = BookmarkDBProxy::NO_HIT;
+    }
+
+    std::for_each( bookmark_entries.begin(),
+                   bookmark_entries.end(),
+                   copy_category( matching_labels ) );
+
+    if ( res == BookmarkDBProxy::FULL_HIT ) {
+        full_hit_it = matching_labels.begin();
+    }
+
+    matching_labels.sort();
+    matching_labels.unique();
+
+    if ( full_hit_it != matching_labels.begin() &&
+         full_hit_it != matching_labels.end() ) {
+        matching_labels.push_front( *full_hit_it );
+        matching_labels.erase( full_hit_it );
+    }
+
+    if ( ( res == BookmarkDBProxy::FULL_HIT || res == BookmarkDBProxy::PREFIX_HIT ) &&
+         matching_labels.empty() == false ) {
+        if ( res == BookmarkDBProxy::FULL_HIT ) {
+            if ( fe ) {
+                fe->setBookmarkMatch( FileEntry::BOOKMARK );
+            } else {
+                es->setBookmarkMatch( FileEntry::BOOKMARK );
+            }
+        } else {
+            if ( fe ) {
+                fe->setBookmarkMatch( FileEntry::BOOKMARK_PREFIX );
+            } else {
+                es->setBookmarkMatch( FileEntry::BOOKMARK_PREFIX );
+            }
+        }
+        if ( fe ) {
+            fe->setMatchingLabels( matching_labels );
+        } else {
+            es->setMatchingLabels( matching_labels );
+        }
+    } else {
+        if ( fe ) {
+            fe->clearMatchingLabels();
+        } else {
+            es->clearMatchingLabels();
+        }
+    }
+
+    return true;
+}
+
 bool DirBookmarksSettings::check( Verzeichnis &v )
 {
     BookmarkDBProxy &bookmarks = Worker::getBookmarkDBInstance();
@@ -60,48 +134,22 @@ bool DirBookmarksSettings::check( Verzeichnis &v )
           it1++ ) {
         FileEntry *fe = *it1;
 
-        std::list< BookmarkDBEntry > bookmark_entries;
-        BookmarkDBProxy::check_path_res_t res = bookmarks.checkPath( fe->fullname, bookmark_entries );
-
-        std::list<std::string> matching_labels;
-        std::list<std::string>::iterator full_hit_it = matching_labels.end();
-
-        if ( bookmark_entries.empty() == true ) {
-            res = BookmarkDBProxy::NO_HIT;
-        }
-
-        std::for_each( bookmark_entries.begin(),
-                       bookmark_entries.end(),
-                       copy_category( matching_labels ) );
-
-        if ( res == BookmarkDBProxy::FULL_HIT ) {
-            full_hit_it = matching_labels.begin();
-        }
-
-        matching_labels.sort();
-        matching_labels.unique();
-
-        if ( full_hit_it != matching_labels.begin() &&
-             full_hit_it != matching_labels.end() ) {
-            matching_labels.push_front( *full_hit_it );
-            matching_labels.erase( full_hit_it );
-        }
-
-        if ( ( res == BookmarkDBProxy::FULL_HIT || res == BookmarkDBProxy::PREFIX_HIT ) &&
-             matching_labels.empty() == false ) {
-            if ( res == BookmarkDBProxy::FULL_HIT ) {
-                fe->setBookmarkMatch( FileEntry::BOOKMARK );
-            } else {
-                fe->setBookmarkMatch( FileEntry::BOOKMARK_PREFIX );
-            }
-            fe->setMatchingLabels( matching_labels );
-        } else {
-            fe->clearMatchingLabels();
-        }
+        checkEntry( bookmarks, fe, NULL );
     }
     return true;
 }
 
+bool DirBookmarksSettings::check( std::vector< NWCEntrySelectionState > &d )
+{
+    BookmarkDBProxy &bookmarks = Worker::getBookmarkDBInstance();
+
+    for ( auto &es : d ) {
+        checkEntry( bookmarks, NULL, &es );
+    }
+
+    return true;
+}
+
 int DirBookmarksSettings::getSerialNr() const
 {
     //TODO check bookmarks serial id to be able to notice changes without explicit notification?
