@@ -1,6 +1,6 @@
 /* dirbookmarkui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2020 Ralf Hoffmann.
+ * Copyright (C) 2007-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -37,6 +37,9 @@
 #include "prefixdb.hh"
 #include "worker.h"
 #include "stringmatcher_flexibleregex.hh"
+#include "async_job_limiter.hh"
+#include "wconfig.h"
+#include <iostream>
 
 DirBookmarkUI::DirBookmarkUI( Worker &worker,
                               AGUIX &aguix,
@@ -660,14 +663,51 @@ void DirBookmarkUI::updateLVData( int row, int field,
         std::string path = m_lv->getText( row, 1 );
 
         if ( m_existence_results.count( path ) == 0 ) {
-            auto f = std::async( std::launch::async,
-                                 [path] {
-                                     return ExistenceTest::checkPathExistence( path );
-                                 } );
-            m_existence_tests.push_back( std::make_tuple( std::move( f ), row, true ) );
+            bool async_started = false;
+            bool do_check = true;
 
-            data.text = "?";
-            data.text_set = true;
+            if ( ! wconfig->getDisableBGCheckPrefix().empty() &&
+                 AGUIXUtils::starts_with( path, wconfig->getDisableBGCheckPrefix() ) ) {
+                do_check = false;
+            }
+            
+            if ( do_check && ! AsyncJobLimiter::async_job_limit_reached() ) {
+                try {
+                    auto f = std::async( std::launch::async,
+                                         [path] {
+                                             AsyncJobLimiter::inc_async_job();
+                                             auto res = ExistenceTest::checkPathExistence( path );
+                                             AsyncJobLimiter::dec_async_job();
+
+                                             return res;
+                                         } );
+                    m_existence_tests.push_back( std::make_tuple( std::move( f ), row, true ) );
+
+                    data.text = "?";
+                    data.text_set = true;
+
+                    async_started = true;
+                } catch ( std::system_error &e ) {
+                    std::cout << e.what() << std::endl;
+                }
+            }
+
+            if ( ! async_started ) {
+                std::promise< ExistenceTest::existence_state_t > promise;
+                auto f = promise.get_future();
+
+                m_existence_tests.push_back( std::make_tuple( std::move( f ), row, true ) );
+
+                if ( do_check ) {
+                    promise.set_value( ExistenceTest::checkPathExistence( path ) );
+                } else {
+                    promise.set_value( { .exists = ExistenceTest::EXISTS_YES,
+                            .path_length = path.size() } );
+                }
+
+                data.text = "?";
+                data.text_set = true;
+            }
         } else {
             auto &res = m_existence_results.at( path );
 
