@@ -221,7 +221,7 @@ void DirFilterSettings::setFilters( const std::list<NM_Filter> &filters )
     _serial_nr++;
 }
 
-std::list<NM_Filter> DirFilterSettings::getFilters() const
+const std::list<NM_Filter> &DirFilterSettings::getFilters() const
 {
     return _filters;
 }
