@@ -1,6 +1,6 @@
 /* dmcacheentrynwc.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2021 Ralf Hoffmann.
+ * Copyright (C) 2012-2024 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,11 +31,14 @@
 #include "wcfiletype.hh"
 #include "aguix/util.h"
 #include "commonprefix.hh"
+#include "stringmatcher_fnmatch.hh"
 
 DMCacheEntryNWC::DMCacheEntryNWC( std::unique_ptr< NWC::Dir > dir,
                                   DirFilterSettings *dir_filter_sets,
                                   DirSortSettings *dir_sort_sets,
-                                  DirBookmarksSettings *dir_bookmarks_sets )
+                                  DirBookmarksSettings *dir_bookmarks_sets,
+                                  std::function< void () > begin_check_cb,
+                                  std::function< void () > end_check_cb )
     : m_dir( dir.release() ),
       m_dir_filter_sets( dir_filter_sets ),
       m_dir_sort_sets( dir_sort_sets ),
@@ -47,7 +50,9 @@ DMCacheEntryNWC::DMCacheEntryNWC( std::unique_ptr< NWC::Dir > dir,
       m_y_offset( -1 ),
       m_unchecked_entries( 0 ),
       m_dont_check_content( false ),
-      m_modification_mode( MOD_UNSET )
+      m_modification_mode( MOD_UNSET ),
+      m_begin_check_cb( begin_check_cb ),
+      m_end_check_cb( end_check_cb )
 {
     setupEntries();
 
@@ -151,16 +156,35 @@ void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &n
 
                     new_es.setSelected( old_es_it->getSelected() );
 
+                    bool apply_old_filetype = true;
+
+                    if ( old_fse->isBrokenLink() ) {
+                        if ( ! new_fse->isBrokenLink() ) {
+                            // old was a broken symlink, but new entry
+                            // is not so do not use the file type
+                            apply_old_filetype = false;
+                        }
+                    } else if ( old_fse->isLink() ) {
+                        if ( new_fse->isBrokenLink() ) {
+                            // old entry was a valid symlink and new
+                            // entry is broken, so do not use the file
+                            // type
+                            apply_old_filetype = false;
+                        }
+                    }
+
                     if ( old_es_it->getFiletype() ) {
                         if ( flags & RESET_FILETYPE_FOR_CHANGED_SIZE_OF_UNKNOWN ) {
-                            // only apply if size is still the same or
-                            // the file type is already known
-                            if ( new_fse->stat_size() == old_fse->stat_size() ||
-                                 old_es_it->getFiletype()->getinternID() != UNKNOWNTYPE ) {
-                                new_es.setFiletype( old_es_it->getFiletype() );
+                            // if size has changed for an unknown
+                            // type, do not apply the unknown type and
+                            // instead let it recheck the actual type
+                            if ( new_fse->stat_size() != old_fse->stat_size() &&
+                                 old_es_it->getFiletype()->getinternID() == UNKNOWNTYPE ) {
+                                apply_old_filetype = false;
                             }
-                        } else {
-                            // always apply
+                        }
+
+                        if ( apply_old_filetype ) {
                             new_es.setFiletype( old_es_it->getFiletype() );
                         }
                     }
@@ -168,6 +192,7 @@ void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &n
                     new_es.setBookmarkInfo( old_es_it->getBookmarkInfo() );
                     new_es.setFiletypeFileOutput( old_es_it->getFiletypeFileOutput() );
                     new_es.setMimeType( old_es_it->getMimeType() );
+                    new_es.setCustomAttribute( old_es_it->getCustomAttribute() );
 
                     NWC::Dir *old_dir = dynamic_cast< NWC::Dir * >( old_fse );
                     NWC::Dir *new_dir = dynamic_cast< NWC::Dir * >( new_fse );
@@ -203,6 +228,44 @@ const NWCEntrySelectionState *DMCacheEntryNWC::getEntry( int pos )
     return &m_entries[pos];
 }
 
+std::pair< const NWCEntrySelectionState *, int > DMCacheEntryNWC::getEntry( const std::string &fullname, int pos, bool also_hidden )
+{
+    if ( pos >= 0 ) {
+        if ( also_hidden || getUse( pos ) ) {
+            auto es = getEntry( pos );
+
+            if ( es ) {
+                auto fse = es->getNWCEntry();
+
+                if ( fse &&
+                     fse->getFullname() == fullname ) {
+                    return std::make_pair( es, pos );
+                }
+            }
+        }
+    }
+
+    for ( pos = 0;
+          pos < (int)getSize();
+          pos++ ) {
+        if ( also_hidden || getUse( pos ) ) {
+            auto es = getEntry( pos );
+
+            if ( ! es ) continue;
+
+            auto fse = es->getNWCEntry();
+
+            if ( ! fse ) continue;
+
+            if ( fse->getFullname() == fullname ) {
+                return std::make_pair( es, pos );
+            }
+        }
+    }
+
+    return { NULL, -1 };
+}
+
 void DMCacheEntryNWC::modifyEntry( int pos,
                                    std::function< void( NWCEntrySelectionState & ) > mod_function )
 {
@@ -250,11 +313,15 @@ void DMCacheEntryNWC::updateView( bool force )
 
     if ( m_dir_filter_sets->getSerialNr() != m_filter_serial_nr || force == true ) {
 
+        if ( m_begin_check_cb ) m_begin_check_cb();
+
         for ( auto &se : m_entries ) {
             if ( se.getNWCEntry()->getBasename() == ".." ) continue;
 
             m_dir_filter_sets->check( dirname, se );
         }
+
+        if ( m_end_check_cb ) m_end_check_cb();
         
         m_filter_serial_nr = m_dir_filter_sets->getSerialNr();
         dirty = true;
@@ -400,14 +467,14 @@ void DMCacheEntryNWC::setActiveEntryPos( int pos )
     m_active_entry.dir_entry_id = m_entries[pos].getEntryID();
 }
 
-std::string DMCacheEntryNWC::getNameOfDir()
+std::string DMCacheEntryNWC::getNameOfDir() const
 {
     if ( ! m_dir.get() ) return "";
 
     return m_dir->getFullname();
 }
 
-bool DMCacheEntryNWC::isRealDir()
+bool DMCacheEntryNWC::isRealDir() const
 {
     if ( ! m_dir.get() ) return false;
 
@@ -551,10 +618,8 @@ void DMCacheEntryNWC::resetFiletypesAndColors()
 
 void DMCacheEntryNWC::checkForDCD()
 {
-    List *dcd = wconfig->getDontCheckDirs();
-    char *tstr;
+    const std::list< WConfigTypes::dont_check_dir > &dcd = wconfig->getDontCheckDirs();
     std::string dirstr;
-    int id;
 
     m_dont_check_content = false;
 
@@ -565,18 +630,21 @@ void DMCacheEntryNWC::checkForDCD()
     }
 
     if ( ! dirstr.empty() ) {
-        if ( dcd ) {
-            id = dcd->initEnum();
-            tstr = (char*)dcd->getFirstElement( id );
+        for ( const auto &d : dcd ) {
+            if ( d.is_pattern ) {
+                StringMatcherFNMatch matcher;
+                matcher.setMatchString( d.dir );
 
-            while ( tstr ) {
-                if ( strncmp( tstr, dirstr.c_str(), strlen( tstr ) ) == 0 ) {
+                if ( matcher.match( dirstr ) ) {
+                    m_dont_check_content = true;
+                    break;
+                }
+            } else {
+                if ( strncmp( d.dir.c_str(), dirstr.c_str(), strlen( d.dir.c_str() ) ) == 0 ) {
                     m_dont_check_content = true;
                     break;
                 }
-                tstr = (char*)dcd->getNextElement( id );
             }
-            dcd->closeEnum( id );
         }
     } else {
         m_dont_check_content = true;
@@ -808,3 +876,12 @@ DMCacheEntryNWC::custom_directory_info_state DMCacheEntryNWC::customDirectoryInf
 {
     return m_custom_directory_info_state;
 }
+
+std::string DMCacheEntryNWC::getBasicDirname()
+{
+    if ( isRealDir() ) {
+        return getNameOfDir();
+    } else {
+        return getCommonPrefix();
+    }
+}
