@@ -145,8 +145,7 @@ void ExeClass::execute()
 
   if ( worker != NULL ) worker->setWaitCursor();
 
-  exestr = "/bin/sh ";
-  exestr += tmpfile;
+  exestr = AGUIXUtils::replace_percent_s_quoted( "/bin/sh %s", tmpfile, NULL );
 
   if ( worker_fclose( fp ) != 0 ) error++;
   fp = NULL;
@@ -210,11 +209,11 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
   fp = NULL;
 
   exestr = "/bin/sh ";
-  exestr += tmpfile;
+  exestr += AGUIX_catTrustedAndUnTrusted2( "", tmpfile );
   exestr += " >";
-  exestr += tmpoutput;
+  exestr += AGUIX_catTrustedAndUnTrusted2( "", tmpoutput );
   exestr += " 2>";
-  exestr += tmperror;
+  exestr += AGUIX_catTrustedAndUnTrusted2( "", tmperror );
   rerg = system( exestr.c_str() );
   d = new Datei();
   if ( d->open( tmpoutput, "r" ) == 0 ) {
