@@ -1,6 +1,6 @@
 /* exprfilter_evalatoms.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2014-2020 Ralf Hoffmann.
+ * Copyright (C) 2014-2024 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -24,6 +24,7 @@
 #include "nwcentryselectionstate.hh"
 #include "wcfiletype.hh"
 #include "wconfig.h"
+#include <algorithm>
 
 ExprAtomStringCmp::ExprAtomStringCmp( const std::string &val,
                                       eval_atom_cmp_t cmp_type ) : ExprAtomCmp( cmp_type ),
@@ -116,6 +117,12 @@ void ExprAtomSizeCmp::eval( const NWCEntrySelectionState &element, ExprFilterEva
     
     loff_t size = fse->stat_size();
 
+    if ( m_follow ) {
+        if ( fse->isLink() && ! fse->isBrokenLink() ) {
+            size = fse->stat_dest_size();
+        }
+    }
+
     switch ( m_cmp_type ) {
         case EAC_LT:
             vm.pushValue( size < m_size );
@@ -150,15 +157,53 @@ void ExprAtomSizeCmp::eval( const NWCEntrySelectionState &element, ExprFilterEva
     }
 }
 
+static void mergeAndList( const std::list< int > &l1,
+                          const std::list< int > &l2,
+                          std::list< int > &out )
+{
+    if ( l1.empty() && l2.empty() ) {
+        // just keep result empty
+        return;
+    }
+
+    if ( l1.empty() || l1.front() == -1 ) {
+        for ( auto &e2 : l2 ) {
+            out.push_back( e2 );
+        }
+
+        return;
+    }
+
+    if ( l2.empty() || l2.front() == -1 ) {
+        for ( auto &e1 : l1 ) {
+            out.push_back( e1 );
+        }
+
+        return;
+    }
+
+    std::set_intersection( l1.cbegin(), l1.cend(),
+                           l2.cbegin(), l2.cend(),
+                           std::back_inserter( out ) );
+}
+
 void ExprAtomAnd::eval( const NWCEntrySelectionState &element, ExprFilterEval &vm )
 {
     try {
-        bool v1 = vm.popValue();
+        auto v1 = vm.popValue();
 
         try {
-            bool v2 = vm.popValue();
+            auto v2 = vm.popValue();
 
-            vm.pushValue( v1 && v2 );
+            if ( v1.result && v2.result ) {
+                std::list< int > res;
+                mergeAndList( v1.attributes,
+                              v2.attributes,
+                              res );
+                vm.pushValue( { true, res } );
+            } else {
+                vm.pushValue( false );
+            }
         } catch ( int ) {
             vm.pushValue( v1 );
             vm.setErrorOccured();
@@ -168,15 +213,64 @@ void ExprAtomAnd::eval( const NWCEntrySelectionState &element, ExprFilterEval &v
     }
 }
 
+static void mergeOrList( const std::list< int > &l1,
+                         const std::list< int > &l2,
+                         std::list< int > &out )
+{
+    if ( l1.empty() && l2.empty() ) {
+        // just keep result empty
+        return;
+    }
+
+    if ( l1.empty() ) {
+        if ( l2.front() >= 0 ) {
+            out.push_back( -1 );
+        }
+        for ( auto &e2 : l2 ) {
+            out.push_back( e2 );
+        }
+
+        return;
+    }
+
+    if ( l2.empty() ) {
+        if ( l1.front() >= 0 ) {
+            out.push_back( -1 );
+        }
+        for ( auto &e1 : l1 ) {
+            out.push_back( e1 );
+        }
+
+        return;
+    }
+
+    // both sides are not empty, no need to add a -1
+    std::set_union( l1.cbegin(), l1.cend(),
+                    l2.cbegin(), l2.cend(),
+                    std::back_inserter( out ) );
+}
+
 void ExprAtomOr::eval( const NWCEntrySelectionState &element, ExprFilterEval &vm )
 {
     try {
-        bool v1 = vm.popValue();
+        auto v1 = vm.popValue();
 
         try {
-            bool v2 = vm.popValue();
+            auto v2 = vm.popValue();
 
-            vm.pushValue( v1 || v2 );
+            if ( v1.result && v2.result ) {
+                std::list< int > res;
+                mergeOrList( v1.attributes,
+                             v2.attributes,
+                             res );
+                vm.pushValue( { true, res } );
+            } else if ( v1.result ) {
+                vm.pushValue( v1 );
+            } else if ( v2.result ) {
+                vm.pushValue( v2 );
+            } else {
+                vm.pushValue( false );
+            }
         } catch ( int ) {
             vm.pushValue( v1 );
             vm.setErrorOccured();
@@ -259,3 +353,66 @@ void ExprAtomTimeCmp::eval( const NWCEntrySelectionState &element, ExprFilterEva
             break;
     }
 }
+
+void ExprAtomContentCmp::eval( const NWCEntrySelectionState &element, ExprFilterEval &vm )
+{
+    auto fse = element.getNWCEntry();
+
+    if ( ! fse ) {
+        vm.pushValue( false );
+        return;
+    }
+
+    if ( ! fse->isReg( m_follow ) ) {
+        vm.pushValue( false );
+        return;
+    }
+
+    std::list< int > matches;
+
+    int res = m_content_checker.checkContent( *fse,
+                                              [&vm]() {
+                                                  return vm.checkInterrupt();
+                                              },
+                                              [&vm]( const std::string &feedback ) {
+                                                  vm.reportFeedback( feedback );
+                                              },
+                                              [&matches]( const NWC::FSEntry &entry, int line_number ) {
+                                                  matches.push_back( line_number );
+                                              } );
+
+    if ( m_cmp_type == EAC_EQ ||
+         m_cmp_type == EAC_APPROX ) {
+        if ( res != 0 ) {
+            vm.pushValue( { true, matches } );
+        } else {
+            vm.pushValue( false );
+        }
+        return;
+    } else if ( m_cmp_type == EAC_NE ) {
+        if ( res == 0 ) {
+            vm.pushValue( { true, matches } );
+        } else {
+            vm.pushValue( false );
+        }
+        return;
+    }
+
+    vm.pushValue( false );
+    return;
+}
+
+void ExprAtomPseudoSkip::eval( const NWCEntrySelectionState &element, ExprFilterEval &vm )
+{
+    // this is a pseudo atom which does nothing
+}
+
+void ExprAtomPseudoSkip::setSkipAtoms( size_t v )
+{
+    m_skip_atoms = v;
+}
+
+size_t ExprAtomPseudoSkip::getSkipAtoms() const
+{
+    return m_skip_atoms;
+}
