@@ -246,7 +246,7 @@ void ExprFilterParser::fexpr()
                                 v1.getValue() == "tm" ) {
 
                         time_t t;
-                        bool rel_time;
+                        bool rel_time = false;
 
                         if ( v3 == ExprToken::DATE ) {
                             if ( AGUIXUtils::parseStringToTime( v3.getValue(), &t ) ) {
