@@ -1,6 +1,6 @@
 /* fileentry.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2022 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -83,6 +83,7 @@ FileEntry::FileEntry()
   use=true;
   isHidden=false;
   isCorrupt = false;
+  exists = false;
   
   reclistQueued = false;
   
@@ -160,6 +161,7 @@ int FileEntry::readInfos( bool update )
     filetype = NULL;
     isCorrupt = false;
     isLink = false;
+    exists = false;
 
     if ( fullname == NULL ) return 1;
 
@@ -179,6 +181,8 @@ int FileEntry::readInfos( bool update )
         statbuf.blocks = stbuf.st_blocks;
         statbuf.rdev = stbuf.st_rdev;
         statbuf.dev = stbuf.st_dev;
+
+        exists = true;
     } else {
         ErrorCount::account_errno( errno );
         isCorrupt = true;
@@ -637,6 +641,17 @@ bool FileEntry::isSameFile( const char *othername, bool follow_symlinks ) const
   return false;
 }
 
+bool FileEntry::isSamePath( const FileEntry *fe ) const
+{
+    if ( ! fe ) return false;
+
+    if ( fullname == NULL || fe->fullname == NULL ) return false;
+  
+    if ( strcmp( fullname, fe->fullname ) == 0 ) return true;
+
+    return false;
+}
+
 FileEntry::FileEntry( const FileEntry &other )
 {
   fullname = ( other.fullname != NULL ) ? dupstring( other.fullname ) : NULL;
@@ -655,6 +670,7 @@ FileEntry::FileEntry( const FileEntry &other )
   select = other.select;
   isLink = other.isLink;
   isCorrupt = other.isCorrupt;
+  exists = other.exists;
 
   // not copied
   contentBuf.content = NULL;
@@ -682,6 +698,7 @@ FileEntry::FileEntry( const NWC::FSEntry &other )
     use = true;
     isHidden = other.isHiddenEntry();
     isCorrupt = other.isBrokenLink();
+    exists = other.entryExists();
 
     reclistQueued = false;
 
