@@ -20,7 +20,7 @@
  */
 
 #include "filelock.hh"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 
 FileLock::FileLock( const std::string &filename ) : m_filename( filename ),
                                                     m_fd( -1 )
