@@ -21,15 +21,15 @@
 
 #include "filereq.h"
 #include "worker_locale.h"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/text.h>
-#include <aguix/message.h>
-#include <aguix/util.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/stringgadget.h>
-#include <aguix/request.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/text.h"
+#include "aguix/message.h"
+#include "aguix/util.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/stringgadget.h"
+#include "aguix/request.h"
 #include "verzeichnis.hh"
 #include "fileentry.hh"
 #include "simplelist.hh"
