@@ -1,6 +1,6 @@
 /* fileviewer.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2017 Ralf Hoffmann.
+ * Copyright (C) 2006-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,6 +33,7 @@
 
 bool FileViewer::global_wrap_mode = false;
 bool FileViewer::global_show_line_numbers_mode = false;
+bool FileViewer::global_use_alt_font_mode = false;
 
 FileViewerDestroyCallback::~FileViewerDestroyCallback()
 {
@@ -40,6 +41,7 @@ FileViewerDestroyCallback::~FileViewerDestroyCallback()
 
 FileViewer::FileViewer( Worker *worker ) : m_use_wrap_mode( global_wrap_mode ),
                                            m_use_show_line_numbers_mode( global_show_line_numbers_mode ),
+                                           m_use_alt_font_mode( global_use_alt_font_mode ),
                                            m_worker( worker )
 {
 }
@@ -58,6 +60,7 @@ void FileViewer::view( const std::list<std::string> &filelist,
 
     fvbg->setLineWrap( m_use_wrap_mode );
     fvbg->setShowLineNumbers( m_use_show_line_numbers_mode );
+    fvbg->setUseAltFont( m_use_alt_font_mode );
 
     fvbg->view( filelist,
 		initial_line_number,
@@ -89,6 +92,11 @@ bool FileViewer::getGlobalShowLineNumbers()
     return global_show_line_numbers_mode;
 }
 
+void FileViewer::setGlobalUseAltFont( bool nv )
+{
+    global_use_alt_font_mode = nv;
+}
+
 void FileViewer::setLineWrap( bool nv )
 {
     m_use_wrap_mode = nv;
