@@ -1,6 +1,6 @@
 /* fileviewerbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2022 Ralf Hoffmann.
+ * Copyright (C) 2010-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -43,7 +43,6 @@ FileViewerBG::FileViewerBG( Worker *worker ) : win( NULL ),
                                                m_wrap_mode( false ),
                                                m_showlinenumbers_mode( false ),
                                                m_use_alt_font( false ),
-                                               ts( NULL ),
                                                tv( NULL ),
                                                search_sg( NULL ),
                                                okb( NULL ),
@@ -66,7 +65,6 @@ FileViewerBG::~FileViewerBG()
 {
     m_destroy_callback = NULL;
     if ( win != NULL ) delete win;
-    if ( ts != NULL ) delete ts;
 }
 
 void FileViewerBG::view( const std::list<std::string> &filelist,
@@ -88,7 +86,6 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     m_filelist = filelist;
     m_destroy_callback = destroy_callback;
     
-    ts = NULL;
     tv = NULL;
     std::list<std::string>::const_iterator it1;
     int w, h, sw, sh;
@@ -126,9 +123,8 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
 
     if ( buildTextView( *it1, ac1, fnt, lencalc ) != 0 ) {
         delete win;
-	win = NULL;
-        if ( ts != NULL ) delete ts;
-	ts = NULL;
+        win = NULL;
+        if ( m_ts ) m_ts.reset();
         return;
     }
 
@@ -246,7 +242,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     tv->setShowLineNumbers( slncb->getState() );
     tv->jumpToLine( initial_line_number, highlight_initial_line );
 
-    if ( ts->incompleteFile() == false ) {
+    if ( m_ts->incompleteFile() == false ) {
         readmoreb->hide();
     }
 
@@ -278,15 +274,15 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                 tv->setShowLineNumbers( msg.choose.state );
             } else if ( msg.choose.button == snp_cb ) {
                 if ( msg.choose.state ) {
-                    ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_HEX );
+                    m_ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_HEX );
                 } else {
-                    ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
+                    m_ts->setConvertMode( TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
                 }
                 tv->textStorageChanged();
             } else if ( msg.choose.button == alt_font_cb ) {
                 std::string fontname = wconfig->getFont( msg.choose.state ? 6 : 4 );
                 RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( fontname.c_str() ) ) );
-                ts->setAWidth( lencalc );
+                m_ts->setAWidth( lencalc );
                 tv->setFont( fontname.c_str() );
                 tv->redraw();
             }
@@ -306,15 +302,15 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
             } else if ( msg.button.button == jumplineb ) {
                 jumpToLine();
             } else if ( msg.button.button == readmoreb ) {
-                ts->readMore();
+                m_ts->readMore();
                 tv->textStorageChanged();
-                if ( ts->incompleteFile() == false ) {
+                if ( m_ts->incompleteFile() == false ) {
                     readmoreb->hide();
                 }
             } else if ( msg.button.button == reloadb ) {
-                ts->reloadFile();
+                m_ts->reloadFile();
                 tv->textStorageChanged();
-                if ( ts->incompleteFile() == false ) {
+                if ( m_ts->incompleteFile() == false ) {
                     readmoreb->hide();
                 }
             } else if ( msg.button.button == m_next_match_b ) {
@@ -354,16 +350,16 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                         break;
                     case XK_r:
                         if ( ( msg.key.keystate & ( ControlMask | Mod1Mask ) ) != 0 ) {
-                            ts->reloadFile();
+                            m_ts->reloadFile();
                             tv->textStorageChanged();
-                            if ( ts->incompleteFile() == false ) {
+                            if ( m_ts->incompleteFile() == false ) {
                                 readmoreb->hide();
                             }
                         } else {
-                            if ( ts->incompleteFile() == true ) {
-                                ts->readMore();
+                            if ( m_ts->incompleteFile() == true ) {
+                                m_ts->readMore();
                                 tv->textStorageChanged();
-                                if ( ts->incompleteFile() == false ) {
+                                if ( m_ts->incompleteFile() == false ) {
                                     readmoreb->hide();
                                 }
                             }
@@ -373,7 +369,7 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                         if ( search_sg->isActive() == true ) {
                             nextMatch();
                         } else {
-                            std::pair<int, int> rl = ts->getRealLinePair( tv->getYOffset() );
+                            std::pair<int, int> rl = m_ts->getRealLinePair( tv->getYOffset() );
                             ts_search->setSearchStartLine( rl.first );
                             search_sg->setText( "" );
                             search_sg->activate();
@@ -386,7 +382,7 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                             if ( search_sg->isActive() == true ) {
                                 nextMatch();
                             } else {
-                                std::pair<int, int> rl = ts->getRealLinePair( tv->getYOffset() );
+                                std::pair<int, int> rl = m_ts->getRealLinePair( tv->getYOffset() );
                                 ts_search->setSearchStartLine( rl.first );
                                 search_sg->setText( "" );
                                 search_sg->activate();
@@ -396,7 +392,7 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                                 alt_font_cb->setState( ! alt_font_cb->getState() );
                                 std::string fontname = wconfig->getFont( alt_font_cb->getState() ? 6 : 4 );
                                 RefCount<AFontWidth> lencalc( new AFontWidth( aguix, aguix->getFont( fontname.c_str() ) ) );
-                                ts->setAWidth( lencalc );
+                                m_ts->setAWidth( lencalc );
                                 tv->setFont( fontname.c_str() );
                                 tv->redraw();
                             }
@@ -431,10 +427,10 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
             break;
         case AG_TEXTVIEW_END_REACHED:
             if ( msg.textview.textview == tv &&
-                 ts->incompleteFile() ) {
-                ts->readMore();
+                 m_ts->incompleteFile() ) {
+                m_ts->readMore();
                 tv->textStorageChanged();
-                if ( ts->incompleteFile() == false ) {
+                if ( m_ts->incompleteFile() == false ) {
                     readmoreb->hide();
                 }
             }
@@ -530,13 +526,10 @@ int FileViewerBG::buildTextView( const std::string &filename,
     if ( tv != NULL ) {
         delete tv;
     }
-    if ( ts != NULL ) {
-        delete ts;
-    }
-    ts = new TextStorageFile( filename, lencalc, initial_size, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
-    tv = new TextView( aguix, 0, 0, 100, 100, "", *ts );
+    m_ts = std::make_shared< TextStorageFile >( filename, lencalc, initial_size, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
+    tv = new TextView( aguix, 0, 0, 100, 100, "", m_ts );
 
-    ts_search.reset( new SearchTextStorage( *ts ) );
+    ts_search.reset( new SearchTextStorage( *m_ts ) );
 
     tv->setDisplayFocus( true );
 
