@@ -20,16 +20,16 @@
  */
 
 #include "fontreq.h"
-#include <aguix/aguix.h>
-#include <aguix/awindow.h>
-#include <aguix/button.h>
-#include <aguix/text.h>
-#include <aguix/message.h>
-#include <aguix/stringgadget.h>
-#include <aguix/fieldlistview.h>
+#include "aguix/aguix.h"
+#include "aguix/awindow.h"
+#include "aguix/button.h"
+#include "aguix/text.h"
+#include "aguix/message.h"
+#include "aguix/stringgadget.h"
+#include "aguix/fieldlistview.h"
 #include "worker_locale.h"
-#include <aguix/util.h>
-#include <aguix/request.h>
+#include "aguix/util.h"
+#include "aguix/request.h"
 #include "simplelist.hh"
 
 #ifdef HAVE_XFT
