@@ -1,6 +1,6 @@
 /* functionproto.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -84,7 +84,7 @@ int FunctionProto::presave(Datei *fh,FunctionProto *fp)
   return 0;
 }
 
-int FunctionProto::run( WPUContext *wpu, ActionMessage *msg )
+int FunctionProto::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
   return 0;
 }
@@ -198,7 +198,15 @@ FunctionProto::command_categories_t FunctionProto::getCategory() const
 
 std::string FunctionProto::getStringRepresentation()
 {
-    return getDescription();
+    std::string res = getDescription();
+
+    if ( m_request_parameters ) {
+        res += " (";
+        res += catalog.getLocale( 1375 );
+        res += ")";
+    }
+
+    return res;
 }
 
 void ActionMessage::setEntriesToConsider( RefCount< NWC::VirtualDir > entries )
@@ -235,3 +243,13 @@ bool FunctionProto::isInteractiveRun() const
 void FunctionProto::setInteractiveRun()
 {
 }
+
+bool FunctionProto::requestParameters() const
+{
+    return m_request_parameters;
+}
+
+void FunctionProto::setRequestParameters( bool nv )
+{
+    m_request_parameters = nv;
+}
