@@ -1,6 +1,6 @@
 /* functionproto.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -60,7 +60,8 @@ public:
                  AM_MODE_ONLYACTIVE,
                  AM_MODE_DNDACTION,
                  AM_MODE_SPECIAL,
-                 AM_MODE_SPECIFIC_ENTRIES } am_mode_t;
+                 AM_MODE_SPECIFIC_ENTRIES,
+                 AM_MODE_ON_DEMAND } am_mode_t;
   am_mode_t mode;
   Lister *startLister;
   const class DNDMsg *dndmsg;
