@@ -1,6 +1,6 @@
 /* goftpop.h
  * This file belongs to Worker, a file manager for UN&X/X11.
- * Copyright (C) 2005-2017 Ralf Hoffmann.
+ * Copyright (C) 2005-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -36,18 +36,16 @@ public:
   GoFTPOp( const GoFTPOp &other );
   GoFTPOp &operator=( const GoFTPOp &other );
 
-  virtual GoFTPOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
-  using FunctionProto::run;
-  virtual int run( WPUContext *wpu, ActionMessage* );
-  virtual bool save(Datei*);
-  virtual const char *getDescription();
-  virtual int configure();
+  GoFTPOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
+  bool save(Datei*) override;
+  const char *getDescription() override;
+  int configure() override;
   
   int doconfigure(int mode);
   
-  void setRequestFlags( bool );
   void setDontEnterFTP( bool );
   void setHost( std::string );
   void setUser( std::string );
@@ -61,7 +59,7 @@ public:
 protected:
   // Infos to save
 
-  bool requestflags, dontenterftp, always_store_pw;
+  bool dontenterftp, always_store_pw;
   std::string host, user, pass;
   std::string avfs_module;
   
