@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -78,7 +78,8 @@ public:
     virtual void registerCommand( const std::string &command,
                                   const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback,
                                   const std::string &description = "",
-                                  FunctionProto::command_categories_t category = FunctionProto::CAT_SCRIPTING );
+                                  FunctionProto::command_categories_t category = FunctionProto::CAT_SCRIPTING,
+                                  const std::function< std::string ( const std::string &current_input ) > help_callback = nullptr );
     virtual void runCommandWithStrArgs( const std::string &command_str );
 
     virtual bool pathsChanged( const std::set< std::string > changed_paths );
@@ -103,8 +104,13 @@ public:
     virtual std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
     virtual std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithArgs() const;
     virtual WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command, bool args ) const;
+    virtual std::string getCommandInputHelp( const std::string &command,
+                                             const std::string &current_input ) const;
+    virtual bool commandHasInputHelp( const std::string &command ) const;
 
     virtual void finalizeBGOps();
+
+    virtual void interpretFinalize();
 protected:
   Lister *parentlister;
   AGUIX *aguix;
@@ -116,7 +122,8 @@ private:
     std::map< std::string, std::function< void ( const std::list< RefCount< ArgClass > > ) > > m_commands_with_args;
     std::map< std::pair< std::string, bool >,
               std::tuple< std::string,
-                          FunctionProto::command_categories_t > > m_command_info;
+                          FunctionProto::command_categories_t,
+                          std::function< std::string ( const std::string &current_input ) > > > m_command_info;
 };
 
 #endif
