@@ -23,7 +23,7 @@
 #define NMROWDATA_H
 
 #include "wdefines.h"
-#include <aguix/fieldlvrowdata.h>
+#include "aguix/fieldlvrowdata.h"
 
 class FileEntry;
 
