@@ -1,6 +1,6 @@
 /* ownop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -37,6 +37,9 @@
 #include "processexitaction.hh"
 #include "execlass.h"
 #include "wconfig.h"
+#include "listermode.h"
+#include "textviewmode.hh"
+#include "virtualdirmode.hh"
 
 const char *OwnOp::name="OwnOp";
 
@@ -76,6 +79,8 @@ OwnOp::duplicate() const
   ta->dontcd = dontcd;
   ta->m_use_virtual_temp_copies = m_use_virtual_temp_copies;
   ta->m_flags_are_relative_to_base_dir = m_flags_are_relative_to_base_dir;
+  ta->m_follow_active = m_follow_active;
+  ta->m_watch_file = m_watch_file;
 
   ta->ownstart=ownstart;
 
@@ -126,6 +131,12 @@ OwnOp::save(Datei *fh)
     case OWNOP_SHOW_OUTPUT_INT:
       fh->configPutPair( "start", "showoutputint" );
       break;
+    case OWNOP_SHOW_OUTPUT_OTHER_SIDE:
+      fh->configPutPair( "start", "showoutputotherside" );
+      break;
+    case OWNOP_SHOW_OUTPUT_CUSTOM_ATTRIBUTE:
+      fh->configPutPair( "start", "showoutputcustomattribute" );
+      break;
     default:
       fh->configPutPair( "start", "normal" );
       break;
@@ -144,6 +155,14 @@ OwnOp::save(Datei *fh)
   if ( m_flags_are_relative_to_base_dir != true ) {
       fh->configPutPairBool( "flagsarerelativetobasedir", m_flags_are_relative_to_base_dir );
   }
+
+  if ( m_follow_active ) {
+      fh->configPutPairBool( "followactive", m_follow_active );
+  }
+  if ( m_watch_file ) {
+      fh->configPutPairBool( "watchfile", m_watch_file );
+  }
+
   return true;
 }
 
@@ -162,6 +181,50 @@ static bool isCorrectViewProg( const char *str )
     return false;
 }
 
+static void updateVisibility( int option,
+                              ChooseButton *scb,
+                              ChooseButton *rcb,
+                              ChooseButton *ibcb,
+                              ChooseButton *tdcb,
+                              ChooseButton *dcdcb,
+                              ChooseButton *virtualcb,
+                              ChooseButton* relflagscb,
+                              ChooseButton *follow_active_cb,
+                              ChooseButton *watch_file_cb )
+{
+    if ( option == 5 ) {
+        scb->hide();
+        rcb->hide();
+        ibcb->hide();
+        tdcb->hide();
+        dcdcb->hide();
+        virtualcb->hide();
+        relflagscb->hide();
+        follow_active_cb->show();
+        watch_file_cb->show();
+    } else if ( option == 6 ) {
+        scb->show();
+        rcb->hide();
+        ibcb->hide();
+        tdcb->hide();
+        dcdcb->show();
+        virtualcb->show();
+        relflagscb->show();
+        follow_active_cb->hide();
+        watch_file_cb->hide();
+    } else {
+        scb->show();
+        rcb->show();
+        ibcb->show();
+        tdcb->show();
+        dcdcb->show();
+        virtualcb->show();
+        relflagscb->show();
+        follow_active_cb->hide();
+        watch_file_cb->hide();
+    }
+}
+
 int
 OwnOp::configure()
 {
@@ -198,7 +261,7 @@ OwnOp::configure()
   win->create();
   _freesafe(tstr);
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 11 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 13 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -228,7 +291,22 @@ OwnOp::configure()
                                                     LABEL_RIGHT,
                                                     0 ), 0, 6, cincwnr );
 
-  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 7 );
+  ChooseButton *follow_active_cb = ac1->addWidget( new ChooseButton( aguix,
+                                                                     0,
+                                                                     0,
+                                                                     ( m_follow_active == true ) ? 1 : 0,
+                                                                     catalog.getLocale( 1184 ),
+                                                                     LABEL_RIGHT,
+                                                                     0 ), 0, 7, cincwnr );
+  ChooseButton *watch_file_cb = ac1->addWidget( new ChooseButton( aguix,
+                                                                  0,
+                                                                  0,
+                                                                  ( m_watch_file == true ) ? 1 : 0,
+                                                                  catalog.getLocale( 1183 ),
+                                                                  LABEL_RIGHT,
+                                                                  0 ), 0, 8, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 9 );
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
@@ -240,6 +318,8 @@ OwnOp::configure()
   cyb->addOption(catalog.getLocale(334));
   cyb->addOption(catalog.getLocale(335));
   cyb->addOption( catalog.getLocale( 911 ) );
+  cyb->addOption( catalog.getLocale( 1512 ) );
+  cyb->addOption( catalog.getLocale( 1535 ) );
   cyb->resize(cyb->getMaxSize(),cyb->getHeight());
   ac1_1->readLimits();
   switch(ownstart) {
@@ -255,12 +335,18 @@ OwnOp::configure()
     case OWNOP_SHOW_OUTPUT_INT:
       cyb->setOption( 4 );
       break;
+    case OWNOP_SHOW_OUTPUT_OTHER_SIDE:
+      cyb->setOption( 5 );
+      break;
+    case OWNOP_SHOW_OUTPUT_CUSTOM_ATTRIBUTE:
+      cyb->setOption( 6 );
+      break;
     default:
       cyb->setOption(0);
       break;
   }
   
-  AContainer *ac1_2 = ac1->add( new AContainer( win, 5, 1 ), 0, 8 );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 5, 1 ), 0, 10 );
   ac1_2->setMinSpace( 0 );
   ac1_2->setMaxSpace( 0 );
   ac1_2->setBorderWidth( 0 );
@@ -276,7 +362,7 @@ OwnOp::configure()
   fb = (Button*)ac1_2->add( new Button( aguix, 0, 0, "O", 0 ), 4, 0, cfix );
   fb->setBubbleHelpText( catalog.getLocale( 1132 ) );
   
-  AContainer *ac1_3 = ac1->add( new AContainer( win, 5, 1 ), 0, 9 );
+  AContainer *ac1_3 = ac1->add( new AContainer( win, 5, 1 ), 0, 11 );
   ac1_3->setMinSpace( 0 );
   ac1_3->setMaxSpace( 0 );
   ac1_3->setBorderWidth( 0 );
@@ -292,13 +378,19 @@ OwnOp::configure()
       sg[1]->show();
       comreqb2->show();
       view_text->show();
+      view_help_b->show();
   } else {
       sg[1]->hide();
       comreqb2->hide();
       view_text->hide();
+      view_help_b->hide();
   }
+  updateVisibility( cyb->getSelectedOption(),
+                    scb, rcb, ibcb, tdcb, dcdcb,
+                    virtualcb, relflagscb,
+                    follow_active_cb, watch_file_cb );
   
-  AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 10 );
+  AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 12 );
   ac1_4->setMinSpace( 5 );
   ac1_4->setMaxSpace( -1 );
   ac1_4->setBorderWidth( 0 );
@@ -430,11 +522,18 @@ OwnOp::configure()
                     sg[1]->show();
                     comreqb2->show();
                     view_text->show();
+                    view_help_b->show();
                 } else {
                     sg[1]->hide();
                     comreqb2->hide();
                     view_text->hide();
+                    view_help_b->hide();
                 }
+                updateVisibility( cyb->getSelectedOption(),
+                                  scb, rcb, ibcb, tdcb, dcdcb,
+                                  virtualcb, relflagscb,
+                                  follow_active_cb, watch_file_cb );
+                aguix->Flush();
             }
             break;
           case AG_KEYPRESSED:
@@ -477,10 +576,18 @@ OwnOp::configure()
       case 4:
         ownstart = OWNOP_SHOW_OUTPUT_INT;
         break;
+      case 5:
+          ownstart = OWNOP_SHOW_OUTPUT_OTHER_SIDE;
+          break;
+      case 6:
+          ownstart = OWNOP_SHOW_OUTPUT_CUSTOM_ATTRIBUTE;
+          break;
       default:
         ownstart=OWNOP_START_NORMAL;
         break;
     }
+    m_follow_active = follow_active_cb->getState();
+    m_watch_file = watch_file_cb->getState();
   }
   
   delete win;
@@ -647,11 +754,20 @@ void OwnOp::setFlagsAreRelativeToBaseDir( bool nv )
     m_flags_are_relative_to_base_dir = nv;
 }
 
+void OwnOp::setFollowActive( bool nv )
+{
+    m_follow_active = nv;
+}
+
+void OwnOp::setWatchFile( bool nv )
+{
+    m_watch_file = nv;
+}
+
 void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     char *tmpname, *tmpoutput, *tstr;
     Datei *fp;
-    int lastsize[2];
     bool useint;
     bool cancel = false;
     bool oldrec, oldtd;
@@ -661,6 +777,57 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
     if ( com_str == NULL ) return;  // nothing to do
     if ( wpu == NULL ) return;
 
+    if ( ownstart == OWNOP_SHOW_OUTPUT_OTHER_SIDE ) {
+        Lister *activelister = msg->getWorker()->getActiveLister();
+        if ( activelister ) {
+            Lister *inactivelister = msg->getWorker()->getOtherLister( activelister );
+            if ( inactivelister ) {
+                inactivelister->switch2Mode( 3 );
+                auto tvm = dynamic_cast< TextViewMode * >( inactivelister->getActiveMode() );
+                if ( tvm ) {
+                    uint32_t options = 0;
+                    if ( m_follow_active ) {
+                        options |= TextViewMode::FOLLOW_ACTIVE;
+                    }
+                    if ( m_watch_file ) {
+                        options |= TextViewMode::WATCH_FILE;
+                    }
+                    tvm->setCommandString( com_str,
+                                           wpu->getBaseDir(),
+                                           options );
+                }
+            }
+        }
+
+        return;
+    } else if ( ownstart == OWNOP_SHOW_OUTPUT_CUSTOM_ATTRIBUTE ) {
+        Lister *activelister = msg->getWorker()->getActiveLister();
+        if ( activelister ) {
+            auto vdm = dynamic_cast< VirtualDirMode * >( activelister->getActiveMode() );
+            if ( vdm ) {
+                oldrec = wpu->getRecursive();
+                oldtd = wpu->getTakeDirs();
+                wpu->setRecursive( false );
+                wpu->setTakeDirs( false );
+                wpu->setUseVirtualTempCopies( m_use_virtual_temp_copies );
+                wpu->setUseExtendedBasename( m_flags_are_relative_to_base_dir );
+
+                vdm->processCustomAttribute( msg,
+                                             { .command_str = com_str,
+                                               .dont_cd = dontcd,
+                                               .global_command = true,
+                                               .separate_each_entry = separate_each_entry
+                                             },
+                                             NULL,
+                                             -1 );
+
+                wpu->setRecursive( oldrec );
+                wpu->setTakeDirs( oldtd );
+            }
+        }
+        return;
+    }
+
     oldrec = wpu->getRecursive();
     oldtd = wpu->getTakeDirs();
     wpu->setRecursive( recursive );
@@ -703,8 +870,6 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                     fp->putString( "\n" );
                 }
             }
-            lastsize[0] = wpu->filelistRealSize( false );
-            lastsize[1] = wpu->filelistRealSize( true );
 
             std::string quoted_tmpoutput = AGUIX_catTrustedAndUnTrusted2( "", tmpoutput );
 
@@ -732,8 +897,8 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                                                      time( NULL ) );
                     
                     if ( separate_each_entry == false ) break;
-                    if ( wpu->filelistRealSize( false ) == 0 ) break;
-                    if ( wpu->filelistRealSize( false ) == lastsize[0] ) {
+                    if ( wpu->filelistEmpty( false ) ) break;
+                    if ( ! wpu->filelistModified( false, true ) ) {
                         // endless loop
                         //TODO: requester
                         break;
@@ -742,7 +907,6 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                     cancel = true;
                     break;
                 }
-                lastsize[0] = wpu->filelistRealSize( false );
             }
             if(  cancel == false ) {
                 std::string exestr;
