@@ -1,6 +1,6 @@
 /* pathjumpop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2021 Ralf Hoffmann.
+ * Copyright (C) 2012-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -55,6 +55,7 @@ PathJumpOp *PathJumpOp::duplicate() const
     ta->m_display_mode = m_display_mode;
     ta->m_include_all_data = m_include_all_data;
     ta->m_hide_non_existing = m_hide_non_existing;
+    ta->m_lock_on_current_dir = m_lock_on_current_dir;
     return ta;
 }
 
@@ -104,6 +105,10 @@ int PathJumpOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
             
         ui.setCurrentDirname( dirname );
         ui.setCurrentBasename( basename );
+
+        if ( m_lock_on_current_dir ) {
+            ui.setStartLockDirectory( dirname );
+        }
     }
 
     PathJumpUI::initial_tab_t show_tab = PathJumpUI::SHOW_BY_TIME;
@@ -136,9 +141,9 @@ int PathJumpOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
         std::list< RefCount< ArgClass > > args;
 
         if ( lm1 ) {
-            args.push_back( new StringArg( sel_path ) );
-            args.push_back( new KeyValueArg( "pathDBStored",
-                                             std::make_shared< BoolArg >( stored ) ) );
+            args.push_back( RefCount< ArgClass >( new StringArg( sel_path ) ) );
+            args.push_back( RefCount< ArgClass >( new KeyValueArg( "pathDBStored",
+                                                                   std::make_shared< BoolArg >( stored ) ) ) );
             lm1->runCommand( "enter_dir", args );
 
             // if ( highlight_entry.empty() == false ) {
@@ -187,6 +192,11 @@ void PathJumpOp::setHideNonExisting( bool v )
     m_hide_non_existing = v;
 }
 
+void PathJumpOp::setLockOnCurrentDir( bool v )
+{
+    m_lock_on_current_dir = v;
+}
+
 bool
 PathJumpOp::save( Datei *fh )
 {
@@ -222,6 +232,10 @@ PathJumpOp::save( Datei *fh )
         fh->configPutPairBool( "hidenonexisting", m_hide_non_existing );
     }
 
+    if ( m_lock_on_current_dir ) {
+        fh->configPutPairBool( "lockoncurrentdir", m_lock_on_current_dir );
+    }
+
     return true;
 }
 
@@ -239,7 +253,7 @@ PathJumpOp::configure()
     win = new AWindow( aguix, 10, 10, 10, 10, title.c_str(), AWindow::AWINDOW_DIALOG );
     win->create();
     
-    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 5 ), true );
+    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 6 ), true );
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
     
@@ -299,7 +313,11 @@ PathJumpOp::configure()
                                                                 catalog.getLocale( 1115 ), LABEL_LEFT, 0 ), 0, 3,
                                               AContainer::CO_INCWNR );
 
-    AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 4 );
+    auto lockoncurrentdir_cb = ac1->addWidget( new ChooseButton( aguix, 0, 0, m_lock_on_current_dir,
+                                                                 catalog.getLocale( 1435 ), LABEL_LEFT, 0 ), 0, 4,
+                                               AContainer::CO_INCWNR );
+
+    AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
     ac1_2->setMinSpace( 5 );
     ac1_2->setMaxSpace( -1 );
     ac1_2->setBorderWidth( 0 );
@@ -369,6 +387,7 @@ PathJumpOp::configure()
         }
         m_include_all_data = iacb->getState();
         m_hide_non_existing = hidenonexisting_cb->getState();
+        m_lock_on_current_dir = lockoncurrentdir_cb->getState();
     }
     
     delete win;
