@@ -1,6 +1,6 @@
 /* pdatei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2019 Ralf Hoffmann.
+ * Copyright (C) 2002-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -72,7 +72,7 @@ int PDatei::open( const char *filename, open_param_t mode )
     return 0;
 }
 
-int PDatei::read( void *buf, int size )
+ssize_t PDatei::read( void *buf, size_t size )
 {
   if ( fd < 0 || buf == NULL || size < 0 ) return -1;
 
