@@ -1,6 +1,6 @@
 /* run_custom_action.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2020 Ralf Hoffmann.
+ * Copyright (C) 2007-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -67,7 +67,7 @@ RunCustomAction *RunCustomAction::duplicate() const
     return ca;
 }
 
-int RunCustomAction::run( WPUContext *wpu, ActionMessage *msg )
+int RunCustomAction::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     normalmoderuncustomaction( msg );
     return 0;
@@ -280,6 +280,15 @@ int RunCustomAction::configure()
                       }
                   }
                   break;
+                case AG_KEYPRESSED:
+                    if ( win->isParent( msg->key.window, false ) == true ) {
+                        switch ( msg->key.key ) {
+                            case XK_Escape:
+                                endmode = 1;
+                                break;
+                        }
+                    }
+                    break;
             }
             aguix->ReplyMessage(msg);
         }
