@@ -1,6 +1,6 @@
 /* scriptop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2021 Ralf Hoffmann.
+ * Copyright (C) 2002-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -83,6 +83,7 @@ ScriptOp::duplicate() const
   ta->setStackNr( stack_nr );
   ta->setPushString( push_string );
   ta->setPushUseOutput( push_useoutput );
+  ta->setPushOutputReturnCode( m_push_output_return_code );
   ta->setIfTest( if_test );
   ta->setIfLabel( if_label );
   ta->setDoDebug( dodebug );
@@ -130,11 +131,24 @@ ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                          ( ( push_useoutput == true ) ? true : false ),
                          WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
           if ( push_useoutput == true ) {
+            int exit_code = 0;
             std::unique_ptr<ExeClass> ec( new ExeClass( msg->getWorker() ) );
             ec->cdDir( wpu->getBaseDir() );
             ec->addCommand( "%s", res_str.c_str() );
-            tstr2 = ec->getOutput( &exeerror );
-            
+
+            if ( m_push_output_return_code ) {
+                tstr2 = NULL;
+                if ( ec->getOutputAndRV( &tstr2, &exit_code, &exeerror ) != 0 ) {
+                    if ( tstr2 ) {
+                        _freesafe( tstr2 );
+                        tstr2 = NULL;
+                    }
+                    exeerror = 3;
+                }
+            } else {
+                tstr2 = ec->getOutput( &exeerror );
+            }
+
             if ( exeerror == 0 ) {
               if ( tstr2 != NULL ) {
                 if ( dodebug == true ) {
@@ -150,6 +164,19 @@ ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                 }
                 wpu->push( stack_nr, tstr2 );
                 _freesafe( tstr2 );
+
+                if ( m_push_output_return_code ) {
+                    std::string s1 = AGUIXUtils::formatStringToString( "%d", WEXITSTATUS( exit_code ) );
+
+                    if ( dodebug == true ) {
+                        Requester req( Worker::getAGUIX() );
+                        auto rs1 = AGUIXUtils::formatStringToString( catalog.getLocale( 485 ),
+                                                                     s1.c_str(), stack_nr );
+                        req.request( catalog.getLocale( 124 ), rs1.c_str(), catalog.getLocale( 11 ) );
+                    }
+
+                    wpu->push( stack_nr, s1 );
+                }
               }
             } else {
               if ( tstr2 != NULL ) _freesafe( tstr2 );
@@ -167,7 +194,7 @@ ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                 _freesafe( reqstr );
 
                 RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
-                TextStorageString ts( str1, lencalc );
+                auto ts = std::make_shared< TextStorageString >( str1, lencalc );
 
                 Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
               }
@@ -299,7 +326,7 @@ ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                   _freesafe( reqstr );
                   
                   RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
-                  TextStorageString ts( str1, lencalc );
+                  auto ts = std::make_shared< TextStorageString >( str1, lencalc );
                   
                   Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
                 }
@@ -351,7 +378,7 @@ ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
                   _freesafe( reqstr );
                   
                   RefCount<AFontWidth> lencalc( new AFontWidth( Worker::getAGUIX(), NULL ) );
-                  TextStorageString ts( str1, lencalc );
+                  auto ts = std::make_shared< TextStorageString >( str1, lencalc );
                   
                   Worker::getRequester()->request( catalog.getLocale( 347 ), ts, catalog.getLocale( 11 ) );
                 }
@@ -427,6 +454,10 @@ ScriptOp::getDescription()
       str1 += ( push_string != NULL ) ? push_string : "";
       str1 += " at stack ";
       str1 += buf;
+
+      if ( m_push_output_return_code ) {
+          str1 += " (including return code)";
+      }
       break;
     case SCRIPT_POP:
       str1 += "pop ";
@@ -541,6 +572,11 @@ void ScriptOp::setPushUseOutput( bool nv )
   push_useoutput = nv;
 }
 
+void ScriptOp::setPushOutputReturnCode( bool nv )
+{
+    m_push_output_return_code = nv;
+}
+
 void ScriptOp::setIfTest( const char *nstr )
 {
   if ( if_test != NULL ) _freesafe( if_test );
@@ -692,7 +728,7 @@ int ScriptOp::configure()
   push_win->create();
   push_win->setBorderWidth( 0 );
 
-  AContainer *push_win_ac1 = push_win->setContainer( new AContainer( push_win, 1, 5 ), true );
+  AContainer *push_win_ac1 = push_win->setContainer( new AContainer( push_win, 1, 6 ), true );
   push_win_ac1->setMinSpace( 5 );
   push_win_ac1->setMaxSpace( 5 );
   push_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 468 ) ), 0, 0, cincwnr );
@@ -700,8 +736,11 @@ int ScriptOp::configure()
   chb = (ChooseButton*)push_win_ac1->add( new ChooseButton( aguix, 0, 0,
 							    ( push_useoutput == true ) ? 1 : 0,
 							    catalog.getLocale( 469 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
+  auto push_rv_cb = push_win_ac1->addWidget( new ChooseButton( aguix, 0, 0,
+                                                               ( m_push_output_return_code == true ) ? 1 : 0,
+                                                               catalog.getLocale( 1529 ), LABEL_RIGHT, 0 ), 0, 2, cincwnr );
 
-  AContainer *push_win_ac1_1 = push_win_ac1->add( new AContainer( push_win, 2, 1 ), 0, 2 );
+  AContainer *push_win_ac1_1 = push_win_ac1->add( new AContainer( push_win, 2, 1 ), 0, 3);
   push_win_ac1_1->setMinSpace( 5 );
   push_win_ac1_1->setMaxSpace( 5 );
   push_win_ac1_1->setBorderWidth( 0 );
@@ -715,7 +754,7 @@ int ScriptOp::configure()
 									      buf,
 									      0 ), 1, 0, cincw );
 
-  AContainer *push_win_ac1_2 = push_win_ac1->add( new AContainer( push_win, 3, 1 ), 0, 3 );
+  AContainer *push_win_ac1_2 = push_win_ac1->add( new AContainer( push_win, 3, 1 ), 0, 4 );
   push_win_ac1_2->setMinSpace( 5 );
   push_win_ac1_2->setMaxSpace( 5 );
   push_win_ac1_2->setBorderWidth( 0 );
@@ -739,7 +778,7 @@ int ScriptOp::configure()
 									   dodebug,
 									   catalog.getLocale( 474 ),
 									   LABEL_RIGHT,
-									   0 ), 0, 4, cincwnr );
+									   0 ), 0, 5, cincwnr );
   
   pop_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( pop_win, 0, 2, cmin );
@@ -1225,6 +1264,7 @@ int ScriptOp::configure()
         type = SCRIPT_PUSH;
         if ( chb->getState() == true ) push_useoutput = true;
         else push_useoutput = false;
+        m_push_output_return_code = push_rv_cb->getState();
         stack_nr = atoi( psnsg->getText() );
         if ( stack_nr < 0 ) stack_nr = 0;
         setPushString( pssg->getText() );
@@ -1336,6 +1376,9 @@ bool ScriptOp::save(Datei *fh)
       break;
   }
   fh->configPutPairBool( "pushuseoutput", push_useoutput );
+  if ( m_push_output_return_code ) {
+      fh->configPutPairBool( "pushoutputreturncode", m_push_output_return_code );
+  }
   fh->configPutPairBool( "dodebug", dodebug );
   fh->configPutPairBool( "wpurecursive", wpu_recursive );
   fh->configPutPairBool( "wputakedirs", wpu_take_dirs );
