@@ -44,6 +44,8 @@
 #include "worker_requests.hh"
 #include "bookmarkdbproxy.hh"
 #include "bookmarkdbentry.hh"
+#include "pers_string_list.hh"
+#include "workerinitialsettings.hh"
 
 static const int searchopbg_timeout = 10;
 
@@ -58,6 +60,9 @@ static const int searchopbg_timeout = 10;
 static std::list<ResultStore*> _stored_results;
 static int _stored_results_changed = 0;
 int SearchOpBG::s_search_number = 1;
+std::shared_ptr< PersistentStringList > SearchOpBG::m_match_name_history;
+std::shared_ptr< PersistentStringList > SearchOpBG::m_match_content_history;
+std::shared_ptr< PersistentStringList > SearchOpBG::m_match_expression_history;
 
 #define DEFAULT_EDIT_COMMAND "{scripts}/xeditor -line {l} {f}"
 
@@ -448,6 +453,26 @@ void SearchOpBG::startSearch()
     DW_SetFollowSymlinks dw1( sets.getFollowSymlinks(), sets.getSearchSameFS() );
     use_dir->walk( dw1 );
 
+    initHistory();
+
+    if ( wconfig->getKVPPool().getEntry( "search.enable_pattern_history" ).value.bool_value ) {
+        if ( ! sets.getMatchName().empty() &&
+             sets.getMatchName() != "*" ) {
+            m_match_name_history->removeEntry( sets.getMatchName() );
+            m_match_name_history->pushFrontEntry( sets.getMatchName() );
+        }
+
+        if ( ! sets.getMatchContent().empty() ) {
+            m_match_content_history->removeEntry( sets.getMatchContent() );
+            m_match_content_history->pushFrontEntry( sets.getMatchContent() );
+        }
+
+        if ( ! sets.getMatchExpression().empty() ) {
+            m_match_expression_history->removeEntry( sets.getMatchExpression() );
+            m_match_expression_history->pushFrontEntry( sets.getMatchExpression() );
+        }
+    }
+
     _sth = new SearchThread( std::unique_ptr<NWC::Dir>( std::move( use_dir ) ),
                              skip_initial_dir );
 
@@ -983,7 +1008,37 @@ void SearchOpBG::createWindow()
     acsw1_1->setMaxSpace( 5 );
     acsw1_1->setBorderWidth( 5 );
 
-    _start_ac = acsw1_1->add( new AContainer( subwin1, 2, 5 ), 0, 0 );
+    AContainer *c1 = acsw1_1->add( new AContainer( subwin1, 2, 1 ), 0, 0 );
+    c1->setMinSpace( 5 );
+    c1->setMaxSpace( 5 );
+    c1->setBorderWidth( 0 );
+
+    if ( wconfig->getKVPPool().getEntry( "search.enable_pattern_history" ).value.bool_value ) {
+        AContainer *history_ac = c1->add( new AContainer( subwin1, 1, 2 ), 1, 0 );
+        history_ac->setMinSpace( 0 );
+        history_ac->setMaxSpace( 0 );
+        history_ac->setBorderWidth( 0 );
+
+        m_history_lv = history_ac->addWidget( new FieldListView( aguix, 0, 0, 150, 10, 0 ), 0, 0, AContainer::CO_INCH );
+        m_history_lv->setHBarState( 0 );
+        m_history_lv->setVBarState( 2 );
+        m_history_lv->setNrOfFields( 1 );
+        m_history_lv->setFieldText( 0, catalog.getLocale( 1595 ) );
+        m_history_lv->setConsiderHeaderWidthForDynamicWidth( true );
+        m_history_lv->setShowHeader( true );
+        m_history_lv->setDefaultColorMode( FieldListView::PRECOLOR_ONLYACTIVE );
+
+        AContainer *history_ac_01 = history_ac->add( new AContainer( subwin1, 2, 1 ), 0, 1 );
+        history_ac_01->setMinSpace( 0 );
+        history_ac_01->setMaxSpace( 0 );
+        history_ac_01->setBorderWidth( 0 );
+        m_history_remove_b = history_ac_01->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1599 ), 0 ), 0, 0, AContainer::CO_INCW );
+        m_history_clear_b = history_ac_01->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1600 ), 0 ), 1, 0, AContainer::CO_INCW );
+    } else {
+        c1->setMaxWidth( 0, 1, 0 );
+    }
+
+    _start_ac = c1->add( new AContainer( subwin1, 2, 5 ), 0, 0 );
     _start_ac->setMinSpace( 5 );
     _start_ac->setMaxSpace( 5 );
     _start_ac->setBorderWidth( 0 );
@@ -998,28 +1053,39 @@ void SearchOpBG::createWindow()
                                                                     0 ), 1, 0, AContainer::CO_INCW );
     _startdir_text->resize( _startdir_text->getWidth(), _startdir_sg->getHeight() );
 
-    AContainer *ac1_2 = _start_ac->add( new AContainer( subwin1, 6, 1 ), 1, 1 );
-    ac1_2->setMinSpace( 5 );
-    ac1_2->setMaxSpace( 5 );
-    ac1_2->setBorderWidth( 0 );
+    AContainer *ac_name_v1 = _start_ac->add( new AContainer( subwin1, 1, 2 ), 1, 1 );
+    ac_name_v1->setMinSpace( 5 );
+    ac_name_v1->setMaxSpace( 5 );
+    ac_name_v1->setBorderWidth( 0 );
+    AContainer *ac_name_v1_row0 = ac_name_v1->add( new AContainer( subwin1, 2, 1 ), 0, 0 );
+    ac_name_v1_row0->setMinSpace( 0 );
+    ac_name_v1_row0->setMaxSpace( 0 );
+    ac_name_v1_row0->setBorderWidth( 0 );
+    AContainer *ac_name_v1_row1 = ac_name_v1->add( new AContainer( subwin1, 5, 1 ), 0, 1 );
+    ac_name_v1_row1->setMinSpace( 5 );
+    ac_name_v1_row1->setMaxSpace( 5 );
+    ac_name_v1_row1->setBorderWidth( 0 );
 
     _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 724 ) ), 0, 1, AContainer::CO_FIXNR + AContainer::ACONT_CENTERV );
 
-    _matchname_sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, "*", 0 ), 0, 0, AContainer::CO_INCW );
-    ac1_2->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1559 ) ), 1, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    m_matchname_separator_sg = ac1_2->addWidget( new StringGadget( aguix, 0, 0, aguix->getTextWidth( "MMM" ) + 8,
+    _matchname_sg = (StringGadget*)ac_name_v1_row0->add( new StringGadget( aguix, 0, 0, 100, "*", 0 ), 0, 0, AContainer::CO_INCW );
+    _matchname_case_cb = (ChooseButton*)ac_name_v1_row0->add( new ChooseButton( aguix, 0, 0, false,
+                                                                      catalog.getLocale( 725 ), LABEL_RIGHT, 0 ), 1, 0, AContainer::CO_FIXNR );
+
+    ac_name_v1_row1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1559 ) ), 0, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    m_matchname_separator_sg = ac_name_v1_row1->addWidget( new StringGadget( aguix, 0, 0, aguix->getTextWidth( "MMM" ) + 8,
                                                                    ",",
-                                                                   0 ), 2, 0, AContainer::CO_FIX );
-    _matchname_regexp_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                        catalog.getLocale( 502 ), LABEL_RIGHT, 0 ), 3, 0, AContainer::CO_FIXNR );
-    _matchname_fullpath_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                          catalog.getLocale( 570 ), LABEL_RIGHT, 0 ), 4, 0, AContainer::CO_FIXNR );
-    _matchname_case_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                      catalog.getLocale( 725 ), LABEL_RIGHT, 0 ), 5, 0, AContainer::CO_FIXNR );
+                                                                   0 ), 1, 0, AContainer::CO_FIX );
+    _matchname_regexp_cb = (ChooseButton*)ac_name_v1_row1->add( new ChooseButton( aguix, 0, 0, false,
+                                                                        catalog.getLocale( 502 ), LABEL_RIGHT, 0 ), 2, 0, AContainer::CO_FIXNR );
+    _matchname_fullpath_cb = (ChooseButton*)ac_name_v1_row1->add( new ChooseButton( aguix, 0, 0, false,
+                                                                          catalog.getLocale( 570 ), LABEL_RIGHT, 0 ), 3, 0, AContainer::CO_FIXNR );
     _matchname_regexp_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
     _matchname_fullpath_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
     _matchname_case_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
-    ac1_2->readLimits();
+    ac_name_v1_row0->readLimits();
+    ac_name_v1_row1->readLimits();
+    ac_name_v1->readLimits();
   
     AContainer *ac1_3 = _start_ac->add( new AContainer( subwin1, 2, 1 ), 1, 2 );
     ac1_3->setMinSpace( 0 );
@@ -1072,13 +1138,7 @@ void SearchOpBG::createWindow()
     ac1_globsets->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1560 ) ), 3, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTERV );
     m_exclude_label_sg = ac1_globsets->addWidget( new StringGadget( aguix, 0, 0, 100, "exclude_search", 0 ), 4, 0, AContainer::CO_INCW );
 
-    m_newsearchb = (Button*)ac1_globsets->add( new Button( aguix,
-                                                           0,
-                                                           0,
-                                                           catalog.getLocale( 728 ),
-                                                           0 ), 6, 0, AContainer::CO_FIX );
-
-    AContainer *ac1_set2 = acsw1_1->add( new AContainer( subwin1, 2, 1 ), 0, 2 );
+    AContainer *ac1_set2 = acsw1_1->add( new AContainer( subwin1, 3, 1 ), 0, 2 );
     ac1_set2->setMinSpace( 5 );
     ac1_set2->setMaxSpace( 5 );
     ac1_set2->setBorderWidth( 0 );
@@ -1087,6 +1147,12 @@ void SearchOpBG::createWindow()
                                                                      catalog.getLocale( 1003 ), LABEL_RIGHT, 0 ),
                                                    0, 0, AContainer::CO_FIXNR );
 
+    m_newsearchb = ac1_set2->addWidget( new Button( aguix,
+                                                    0,
+                                                    0,
+                                                    catalog.getLocale( 728 ),
+                                                    0 ), 2, 0, AContainer::CO_FIX );
+
     AWindow *subwin2 = new AWindow( aguix, 0, 0, 10, 10, "" );
     m_options_k1->add( subwin2 );
     subwin2->create();
@@ -1306,6 +1372,8 @@ void SearchOpBG::createWindow()
 
     updateWindowTitle();
 
+    updateHistory( _matchname_sg, false );
+
     return;
 }
 
@@ -1377,6 +1445,10 @@ void SearchOpBG::handleAGUIXMessage( AGMessage &msg )
             } else if ( msg.button.button == m_size_help_b ) {
                 Requester req( aguix, m_win );
                 req.request( catalog.getLocale( 124 ), catalog.getLocale( 820 ), catalog.getLocale( 11 ) );
+            } else if ( msg.button.button == m_history_remove_b ) {
+                removeHistoryItem( false );
+            } else if ( msg.button.button == m_history_clear_b ) {
+                removeHistoryItem( true );
             }
 
             for ( size_t pos = 0; pos < m_expression_help_buttons.size(); pos++ ) {
@@ -1413,6 +1485,11 @@ void SearchOpBG::handleAGUIXMessage( AGMessage &msg )
                 if ( _resultlv->isValidRow( row ) == true ) {
                     storeActiveRow( row );
                 }
+            } else if ( msg.fieldlv.lv == m_history_lv ) {
+                int row = m_history_lv->getActiveRow();
+                if ( m_history_lv->isValidRow( row ) == true ) {
+                    advanceHistoryItem( 0 );
+                }
             }
             break;
         case AG_FIELDLV_DOUBLECLICK:
@@ -1454,6 +1531,18 @@ void SearchOpBG::handleAGUIXMessage( AGMessage &msg )
         case AG_STRINGGADGET_CONTENTCHANGE:
             if ( msg.stringgadget.sg == m_match_expression_sg ) {
                 updateExpressionHelp();
+                updateHistory( msg.stringgadget.sg, true );
+            } else if ( msg.stringgadget.sg == _matchname_sg ||
+                        msg.stringgadget.sg == _matchcontent_sg ||
+                        msg.stringgadget.sg == m_match_expression_sg ) {
+                updateHistory( msg.stringgadget.sg, true );
+            }
+            break;
+        case AG_STRINGGADGET_ACTIVATE:
+            if ( msg.stringgadget.sg == _matchcontent_sg ||
+                 msg.stringgadget.sg == _matchname_sg ||
+                 msg.stringgadget.sg == m_match_expression_sg ) {
+                updateHistory( msg.stringgadget.sg, false );
             }
             break;
         case AG_KEYPRESSED:
@@ -1479,6 +1568,10 @@ void SearchOpBG::handleAGUIXMessage( AGMessage &msg )
                     removeSelectedResults();
                 } else if ( msg.key.key == XK_F5 ) {
                     newSearch();
+                } else if ( msg.key.key == XK_Down ) {
+                    advanceHistoryItem( 1 );
+                } else if ( msg.key.key == XK_Up ) {
+                    advanceHistoryItem( -1 );
                 }
             }
             break;
@@ -1665,3 +1758,156 @@ void SearchOpBG::updateExpressionHelp()
                        _start_ac->getHeight() );
     _start_ac->rearrange();
 }
+
+void SearchOpBG::updateHistory( StringGadget *sg, bool manual_change )
+{
+    if ( ! m_history_lv ) return;
+
+    if ( sg == _matchname_sg ) {
+        m_history_lv->setFieldText( 0, catalog.getLocale( 1596 ) );
+
+        initHistory();
+        m_current_match_history = m_match_name_history;
+    } else if ( sg == _matchcontent_sg ) {
+        m_history_lv->setFieldText( 0, catalog.getLocale( 1597 ) );
+
+        initHistory();
+        m_current_match_history = m_match_content_history;
+    } else if ( sg == m_match_expression_sg ) {
+        m_history_lv->setFieldText( 0, catalog.getLocale( 1598 ) );
+
+        initHistory();
+        m_current_match_history = m_match_expression_history;
+    }
+
+    m_history_lv->setSize( 0 );
+
+    auto l = m_current_match_history->getList();
+
+    StringMatcherFlexibleMatch matcher;
+    matcher.setMatchString( sg->getText() );
+
+    for ( const auto &s : l ) {
+        if ( manual_change && ! matcher.match( s ) ) continue;
+
+        int r = m_history_lv->addRow();
+
+        m_history_lv->setText( r, 0, s );
+
+        if ( s == sg->getText() ) {
+            m_history_lv->setActiveRow( r );
+            m_history_lv->centerActive();
+        }
+    }
+
+    m_history_lv->redraw();
+}
+
+void SearchOpBG::initHistory()
+{
+    std::string str1;
+
+    str1 = WorkerInitialSettings::getInstance().getConfigBaseDir();
+
+#ifdef USEOWNCONFIGFILES
+#define FILESUFFIX "-dev"
+#else
+#define FILESUFFIX ""
+#endif
+
+    if ( ! m_match_name_history ) {
+        std::string str2 = NWC::Path::join( str1, "search-match-name-history" FILESUFFIX );
+        m_match_name_history = std::shared_ptr< PersistentStringList >( new PersistentStringList( str2 ) );
+    }
+
+    if ( ! m_match_content_history ) {
+        std::string str2 = NWC::Path::join( str1, "search-match-content-history" FILESUFFIX );
+        m_match_content_history = std::shared_ptr< PersistentStringList >( new PersistentStringList( str2 ) );
+    }
+
+    if ( ! m_match_expression_history ) {
+        std::string str2 = NWC::Path::join( str1, "search-match-expression-history" FILESUFFIX );
+        m_match_expression_history = std::shared_ptr< PersistentStringList >( new PersistentStringList( str2 ) );
+    }
+}
+
+void SearchOpBG::advanceHistoryItem( int direction )
+{
+    if ( ! m_history_lv ) return;
+
+    if ( m_history_lv->getElements() < 1 ) return;
+
+    int row = m_history_lv->getActiveRow();
+
+    if ( direction != 0 ) {
+        if ( ! m_history_lv->isValidRow( row ) ) {
+            if ( direction < 0 ) {
+                row = m_history_lv->getElements() - 1;
+            } else if ( direction > 0 ) {
+                row = 0;
+            }
+        } else {
+            if ( direction < 0 ) {
+                if ( row == 0 ) return;
+                row--;
+            } else if ( direction > 0 ) {
+                if ( row == m_history_lv->getElements() - 1 ) return;
+                row++;
+            }
+        }
+    }
+
+    auto s = m_history_lv->getText( row, 0 );
+    m_history_lv->setActiveRow( row );
+    m_history_lv->centerActive();
+    m_history_lv->redraw();
+
+    if ( m_current_match_history == m_match_name_history ) {
+        _matchname_sg->setText( s.c_str() );
+    } else if ( m_current_match_history == m_match_content_history ) {
+        _matchcontent_sg->setText( s.c_str() );
+    } else if ( m_current_match_history == m_match_expression_history ) {
+        m_match_expression_sg->setText( s.c_str() );
+        updateExpressionHelp();
+    }
+}
+
+void SearchOpBG::removeHistoryItem( bool all )
+{
+    if ( ! m_history_lv ) return;
+
+    if ( ! m_current_match_history ) return;
+
+    if ( all ) {
+        m_current_match_history->clear();
+
+        if ( m_current_match_history == m_match_name_history ) {
+            _matchname_sg->setText( "*" );
+            updateHistory( _matchname_sg, false );
+        } else if ( m_current_match_history == m_match_content_history ) {
+            _matchcontent_sg->setText( "" );
+            updateHistory( _matchcontent_sg, false );
+        } else if ( m_current_match_history == m_match_expression_history ) {
+            m_match_expression_sg->setText( "" );
+            updateHistory( m_match_expression_sg, false );
+            updateExpressionHelp();
+        }
+
+        return;
+    }
+
+    int row = m_history_lv->getActiveRow();
+    if ( ! m_history_lv->isValidRow( row ) ) return;
+
+    auto s = m_history_lv->getText( row, 0 );
+
+    m_current_match_history->removeEntry( s );
+
+    if ( m_current_match_history == m_match_name_history ) {
+        updateHistory( _matchname_sg, false );
+    } else if ( m_current_match_history == m_match_content_history ) {
+        updateHistory( _matchcontent_sg, false );
+    } else if ( m_current_match_history == m_match_expression_history ) {
+        updateHistory( m_match_expression_sg, false );
+    }
+}
