@@ -391,13 +391,15 @@ void SearchThread::setSearchSettings( const SearchSettings &sets )
     if ( m_sets.getMatchExpression().empty() ) {
         m_expr_filter.reset();
     } else {
+        ExprFilterOptions options;
+        options.disabled_tokens = {
+            "type",
+            "state"
+        };
+        options.follow = sets.getFollowSymlinks();
+
         m_expr_filter = std::make_unique< ExprFilter >( m_sets.getMatchExpression(),
-                                                        ExprFilterOptions{ .disabled_tokens = {
-                                                                "type",
-                                                                "state"
-                                                            },
-                                                                           .follow = sets.getFollowSymlinks()
-                                                        } );
+                                                        options );
         m_expr_filter->setCheckInterrupt( [this]() { return checkInterrupt(); } );
         m_expr_filter->setFeedbackCallback( [this]( const std::string &feedback ) {
             _current_action_lock.lock();
