@@ -1,6 +1,6 @@
 /* showdircacheop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2004,2013 Ralf Hoffmann.
+ * Copyright (C) 2002-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,12 +35,11 @@ public:
   ShowDirCacheOp( const ShowDirCacheOp &other );
   ShowDirCacheOp &operator=( const ShowDirCacheOp &other );
 
-  virtual ShowDirCacheOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
-  using FunctionProto::run;
-  int run( WPUContext *wpu, ActionMessage* );
-  virtual const char *getDescription();
+  ShowDirCacheOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
+  const char *getDescription() override;
 
   static const char *name;
 protected:
