@@ -29,10 +29,10 @@
 #include "configparser.hh"
 #include "fileentry.hh"
 #include "nmspecialsourceext.hh"
-#include <aguix/stringgadget.h>
-#include <aguix/button.h>
-#include <aguix/fieldlistview.h>
-#include <aguix/awindow.h>
+#include "aguix/stringgadget.h"
+#include "aguix/button.h"
+#include "aguix/fieldlistview.h"
+#include "aguix/awindow.h"
 #include "datei.h"
 #include "simplelist.hh"
 
