@@ -1,6 +1,6 @@
 /* simplelist.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2007 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -226,6 +226,14 @@ void *List::getNextElement(int id)
   return acts[id]->element;
 }
 
+bool List::hasNextElement( int id )
+{
+    if ( id < 0 || id >= enums ) return false;
+    if ( acts[id] == NULL ) return false;
+    if ( acts[id]->next ) return true;
+    return false;
+}
+
 void *List::getFirstElement()
 {
   if(first==NULL) return NULL;
