@@ -1,6 +1,6 @@
 /* stringmatcher_flexibleregex.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013 Ralf Hoffmann.
+ * Copyright (C) 2013-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,7 +27,9 @@
 StringMatcherFlexibleRegEx::StringMatcherFlexibleRegEx() :
     m_match_case_sensitive( false ),
     m_compiled( false ),
+#ifdef HAVE_REGEX
     m_groups( NULL ),
+#endif
     m_ngroups( 0 ),
     m_flexible_mode_enabled( true )
 {
@@ -35,11 +37,13 @@ StringMatcherFlexibleRegEx::StringMatcherFlexibleRegEx() :
 
 StringMatcherFlexibleRegEx::~StringMatcherFlexibleRegEx()
 {
+#ifdef HAVE_REGEX
     if ( m_compiled ) {
         regfree( &m_compiled_regex );
     }
 
     free( m_groups );
+#endif
 }
 
 bool StringMatcherFlexibleRegEx::match( const std::string &str )
@@ -71,6 +75,7 @@ bool StringMatcherFlexibleRegEx::getMatchCaseSensitive() const
 
 std::vector< size_t > StringMatcherFlexibleRegEx::getMatchSegments( const std::string &str )
 {
+#ifdef HAVE_REGEX
     if ( m_compiled && m_ngroups > 1 ) {
         int erg = regexec( &m_compiled_regex, str.c_str(), m_ngroups, m_groups, 0 );
         if ( erg == 0 ) {
@@ -103,6 +108,7 @@ std::vector< size_t > StringMatcherFlexibleRegEx::getMatchSegments( const std::s
             return res;
         }
     }
+#endif
 
     return { str.length() };
 }
@@ -180,6 +186,7 @@ void StringMatcherFlexibleRegEx::convertToRegEx()
 
     m_reg_ex_string += ".*";
 
+#ifdef HAVE_REGEX
     if ( m_compiled ) {
         regfree( &m_compiled_regex );
     }
@@ -195,6 +202,7 @@ void StringMatcherFlexibleRegEx::convertToRegEx()
     } else {
         m_compiled = false;
     }
+#endif
 }
 
 void StringMatcherFlexibleRegEx::setMatchFlexible( bool nv )
