@@ -1,6 +1,6 @@
 /* tabprofilesop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017-2021 Ralf Hoffmann.
+ * Copyright (C) 2017-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -159,7 +159,7 @@ std::pair< std::vector< std::string >, std::vector< std::string > > TabProfilesO
 }
 
 void TabProfilesOp::show_profile_content( const std::string &profile_name,
-                                          TextStorageString *storage,
+                                          std::shared_ptr< TextStorageString > storage,
                                           TextView *tv )
 {
     auto content = getProfile( profile_name );
@@ -390,7 +390,7 @@ TabProfilesOp::gui()
     ac1->setMaxSpace( 5 );
   
     RefCount<AFontWidth> lencalc( new AFontWidth( aguix, NULL ) );
-    TextStorageString help_ts( catalog.getLocale( 1195 ), lencalc );
+    auto help_ts = std::make_shared< TextStorageString >( catalog.getLocale( 1195 ), lencalc );
     TextView *help_tv = ac1->addWidget( new TextView( aguix,
                                                       0, 0, 50, 80, "", help_ts ),
                                         0, 0, AContainer::CO_INCW );
@@ -496,7 +496,7 @@ TabProfilesOp::gui()
     acsw12_2_1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1199 ), 1, 0 ),
                            0, 0, AContainer::CO_INCWNR );
 
-    TextStorageString content_ts( "", lencalc );
+    auto content_ts = std::make_shared< TextStorageString >( "", lencalc );
     TextView *content_tv = acsw12_2_1->addWidget( new TextView( aguix,
                                                                 0, 0, 200, 150, "", content_ts ),
                                                   0, 1, AContainer::CO_MIN );
@@ -637,7 +637,7 @@ TabProfilesOp::gui()
                                         if ( ! load_profiles_lv->isValidRow( load_profiles_lv->getActiveRow() ) &&
                                              load_profiles_lv->getElements() > 0 ) {
                                             load_profiles_lv->setActiveRow( 0 );
-                                            show_profile_content( load_profiles_lv->getText( 0, 0 ), &content_ts, content_tv );
+                                            show_profile_content( load_profiles_lv->getText( 0, 0 ), content_ts, content_tv );
                                         }
                                     }
                                 }
@@ -705,7 +705,7 @@ TabProfilesOp::gui()
 
                         row = load_profiles_lv->getActiveRow();
                         if ( load_profiles_lv->isValidRow( row ) == true ) {
-                            show_profile_content( load_profiles_lv->getText( row, 0 ), &content_ts, content_tv );
+                            show_profile_content( load_profiles_lv->getText( row, 0 ), content_ts, content_tv );
                         }
                     }
                     break;
@@ -719,7 +719,7 @@ TabProfilesOp::gui()
                     } else if ( msg->fieldlv.lv == load_profiles_lv ) {
                         int row = load_profiles_lv->getActiveRow();
                         if ( load_profiles_lv->isValidRow( row ) == true ) {
-                            show_profile_content( load_profiles_lv->getText( row, 0 ), &content_ts, content_tv );
+                            show_profile_content( load_profiles_lv->getText( row, 0 ), content_ts, content_tv );
                         }
                     }
                 default:
