@@ -1,6 +1,6 @@
 /* temporaryfilecache.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011-2020 Ralf Hoffmann.
+ * Copyright (C) 2011-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "worker_locale.h"
 #include "aguix/lowlevelfunc.h"
 #include "aguix/request.h"
+#include "nwc_path.hh"
 #include <iostream>
 
 TemporaryFileCache *TemporaryFileCache::m_instance = NULL;
@@ -168,12 +169,16 @@ int TemporaryFileCache::createTempFile( const std::string &filename,
 
     if ( worker_lstat( filename.c_str(), &stbuf ) != 0 ) return 1;
 
-    if ( ! S_ISREG( stbuf.st_mode ) ) return 1;
+    if ( ! S_ISREG( stbuf.st_mode ) &&
+         ! S_ISLNK( stbuf.st_mode ) ) {
+        return 1;
+    }
 
-    std::string::size_type pos = filename.rfind( "." );
+    auto basename = NWC::Path::basename( filename );
+    std::string::size_type pos = basename.rfind( "." );
 
     if ( pos != std::string::npos ) {
-        std::string suffix( filename, pos );
+        std::string suffix( basename, pos );
         newtempname = Datei::createTMPName( NULL, suffix.c_str() );
     } else {
         newtempname = Datei::createTMPName();
@@ -182,7 +187,7 @@ int TemporaryFileCache::createTempFile( const std::string &filename,
     if ( newtempname == NULL ) return 1;
 
     if ( Datei::copyfile( newtempname, filename.c_str(),
-                          progress_callback ) != 0 ) {
+                          progress_callback, true ) != 0 ) {
         if ( Worker::getRequester() != NULL ) {
             char *reqstr;
             reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 618 ) ) + filename.length() + 1 );
