@@ -1,6 +1,6 @@
 /* textstoragefile.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2022 Ralf Hoffmann.
+ * Copyright (C) 2005-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,7 +29,7 @@ class TextStorageFile : public TextStorage
  public:
   TextStorageFile( const std::string &filename,
                    const RefCount<AWidth> &lencalc,
-                   int initial_size,
+                   size_t initial_size,
                    enum TextStorageString::text_storage_converion convert );
   int getNrOfLines() const;
   int getLine( int line_nr, unsigned int offset, int len, std::string &return_line ) const;
@@ -60,23 +60,23 @@ class TextStorageFile : public TextStorage
                            std::string &return_line ) const;
   std::pair< std::pair< int, int >, int > getLineForOffset( int unwrapped_line_nr, int line_offset ) const;
 
-  void readMore( int size = 0 );
+  void readMore( size_t size = 0 );
   void reloadFile();
   bool incompleteFile();
 
-    void setFileName( const std::string &filename, int initial_size = 0 );
-    int getCurrentSize() const;
+    void setFileName( const std::string &filename, size_t initial_size = 0 );
+    size_t getCurrentSize() const;
 
     void setConvertMode( enum TextStorageString::text_storage_converion convert );
 private:
   TextStorageString m_tss;
 
   std::string m_filename;
-  int m_current_size;
+  size_t m_current_size;
   RefCount<AWidth> m_lencalc;
 
   bool m_incomplete_file;
-  int m_file_size;
+  ssize_t m_file_size;
   enum TextStorageString::text_storage_converion m_convert;
 
   void readFile();
