@@ -1,6 +1,6 @@
 /* view_newest_files_op.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2016-2021 Ralf Hoffmann.
+ * Copyright (C) 2016-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -310,9 +310,9 @@ void ViewNewestFilesOp::openWindow()
     cont0->setMaxSpace( 5 );
 
     RefCount<AFontWidth> lencalc( new AFontWidth( m_aguix, NULL ) );
-    m_help_ts = std::unique_ptr< TextStorageString >( new TextStorageString( catalog.getLocale( 1168 ), lencalc ) );
+    m_help_ts = std::shared_ptr< TextStorageString >( new TextStorageString( catalog.getLocale( 1168 ), lencalc ) );
     TextView *help_tv = cont0->addWidget( new TextView( m_aguix,
-                                                        0, 0, 50, 80, "", *m_help_ts ),
+                                                        0, 0, 50, 80, "", m_help_ts ),
                                           0, 0, AContainer::CO_INCW );
     help_tv->setLineWrap( true );
     help_tv->maximizeYLines( 10, 500 );
