@@ -75,7 +75,9 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
     ft_request_list_clear();
   
     if ( getCurrentDirectory() == co->destdir ) {
-        co->do_rename = true;
+        if ( ! co->external_sources ) {
+            co->do_rename = true;
+        }
         updatevdm = this;
     } else {
         Lister *olister = parentlister->getWorker()->getOtherLister( parentlister );
@@ -133,7 +135,8 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
         switch ( co->source ) {
             case copyorder::COPY_SPECIAL:
                 copySourceList( co->sources,
-                                copylist );
+                                copylist,
+                                co->external_sources );
                 break;
             case copyorder::COPY_ONLYACTIVE:
                 getSelFiles( copylist, LM_GETFILES_ONLYACTIVE, false );
@@ -634,7 +637,8 @@ void VirtualDirMode::process_bg_messages()
         if ( ! cs ) continue;
 
         if ( msg.m_type == CopyBGMessage::PRE_MESSAGE &&
-             cs->m_detached == false ) {
+             cs->m_detached == false &&
+             cs->m_cc->getCopyOrder()->external_sources == false ) {
             int row = getRowForCEPos( msg.m_id, cs->m_cc->getCopyOrder()->move );
             int actual_row = row - cs->m_row_adjustment;
             if ( actual_row >= 0 ) {
@@ -656,7 +660,8 @@ void VirtualDirMode::process_bg_messages()
                 }
             }
         } else if ( msg.m_type == CopyBGMessage::POST_MESSAGE ) {
-            if ( cs->m_detached == false ) {
+            if ( cs->m_detached == false &&
+                 cs->m_cc->getCopyOrder()->external_sources == false ) {
                 if ( cs->m_cc->getCopyOrder()->move == false ) {
                     // just copy
 
@@ -739,7 +744,7 @@ void VirtualDirMode::process_bg_messages()
                         }
                     }
                 }
-            } else {
+            } else if ( cs->m_cc->getCopyOrder()->external_sources == false ) {
                 if ( cs->m_cc->getCopyOrder()->move == false ) {
                     cs->m_entries_to_deselect.push_back( msg.m_source_fullname );
                 } else {
@@ -757,6 +762,10 @@ void VirtualDirMode::process_bg_messages()
                         cs->m_cc->setCancel( true );
                     }
                 }
+            } else {
+                if ( msg.m_res == CopyCore::NM_COPY_CANCEL ) {
+                    cs->m_cc->setCancel( true );
+                }
             }
         }
     }
