@@ -1,6 +1,6 @@
 /* volumemanagerui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2022 Ralf Hoffmann.
+ * Copyright (C) 2009-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -39,12 +39,12 @@
 
 VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_aguix( aguix ),
                                                                            m_hwman( hwman ),
-                                                                           m_status_info( "",
-                                                                                          RefCount<AWidth>( new AFontWidth( &aguix,
-                                                                                                                            NULL ) ) ),
-									   m_eject_menu( NULL ),
-									   m_menu_command( VOLMANUI_MENU_EJECT )
+                                                                           m_eject_menu( NULL ),
+                                                                           m_menu_command( VOLMANUI_MENU_EJECT )
 {
+    m_status_info = std::make_shared< TextStorageString >( "",
+                                                           RefCount<AWidth>( new AFontWidth( &aguix,
+                                                                                             NULL ) ) );
     std::string cfgfile = getHiddenDevicesFile();
     m_hide_entries = std::unique_ptr< PersistentStringList >( new PersistentStringList( cfgfile ) );
 
@@ -106,7 +106,10 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
                                                              catalog.getLocale( 888 ),
                                                              0 ),
                                                  0, 4, AContainer::CO_FIX ) );
-    m_updateb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 922 ), 0 ),
+
+    bool dbus_disconnected = m_hwman.systemConnectionFailed();
+
+    m_updateb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, dbus_disconnected ? catalog.getLocale( 1527 ) : catalog.getLocale( 922 ), 0 ),
 						   0, 5, AContainer::CO_FIX ) );
     AContainer *cont7 = cont0->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
     cont7->setBorderWidth( 0 );
@@ -115,6 +118,11 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     
     cont7->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 876 ) ),
                 0, 0, AContainer::CO_FIX );
+
+    if ( dbus_disconnected ) {
+        m_status_info->setContent( catalog.getLocale( 1528 ) );
+    }
+    
     m_status_tv = new TextView( &m_aguix, 0, 0, 100, 50, "", m_status_info );
     cont7->add( m_status_tv, 1, 0, AContainer::CO_INCW );
     m_status_tv->create();
@@ -226,8 +234,23 @@ int VolumeManagerUI::mainLoop()
                           ejectOrCloseTray( VOLMANUI_MENU_CLOSETRAY );
                       }
                   } else if ( msg->button.button == m_updateb ) {
-		      updateLV();
-		      maximizeWin();
+                      if ( m_hwman.systemConnectionFailed() ) {
+                          if ( m_hwman.retrySystemConnection() == 0 ) {
+                              m_status_info->setContent( catalog.getLocale( 1525 ) );
+                              m_status_tv->textStorageChanged();
+                              m_updateb->setText( 0, catalog.getLocale( 922 ) );
+                              updateLV();
+                              maximizeWin();
+                              m_aguix.Flush();
+                          } else {
+                              m_status_info->setContent( catalog.getLocale( 1526 ) );
+                              m_status_tv->textStorageChanged();
+                              m_aguix.Flush();
+                          }
+                      } else {
+                          updateLV();
+                          maximizeWin();
+                      }
                   } else if ( msg->button.button == m_hideb ) {
                       if ( msg->button.state == 2 ) {
                           editHideList();
@@ -432,16 +455,16 @@ void VolumeManagerUI::mountRow( int row )
         HWVolume vol = m_row_to_volume[row];
 
         m_win->setCursor( AGUIX::WAIT_CURSOR );
-        m_status_info.setContent( catalog.getLocale( 878 ) );
+        m_status_info->setContent( catalog.getLocale( 878 ) );
         m_status_tv->textStorageChanged();
         m_aguix.Flush();
 
         std::string error;
         
         if ( m_hwman.mount( vol, error ) == 0 ) {
-            m_status_info.setContent( catalog.getLocale( 879 ) );
+            m_status_info->setContent( catalog.getLocale( 879 ) );
         } else {
-            m_status_info.setContent( error );
+            m_status_info->setContent( error );
         }
         m_status_tv->textStorageChanged();
 
@@ -458,16 +481,16 @@ void VolumeManagerUI::unmountRow( int row )
         HWVolume vol = m_row_to_volume[row];
 
         m_win->setCursor( AGUIX::WAIT_CURSOR );
-        m_status_info.setContent( catalog.getLocale( 880 ) );
+        m_status_info->setContent( catalog.getLocale( 880 ) );
         m_status_tv->textStorageChanged();
         m_aguix.Flush();
 
         std::string error;
 
         if ( m_hwman.umount( vol, error ) == 0 ) {
-            m_status_info.setContent( catalog.getLocale( 881 ) );
+            m_status_info->setContent( catalog.getLocale( 881 ) );
         } else {
-            m_status_info.setContent( error );
+            m_status_info->setContent( error );
         }
         m_status_tv->textStorageChanged();
 
@@ -645,7 +668,7 @@ void VolumeManagerUI::buildEjectMenu( const menu_command_t &menu_command )
     }
 
     if ( m_ejectable_devices.size() < 1 ) {
-        m_status_info.setContent( catalog.getLocale( 934 ) );
+        m_status_info->setContent( catalog.getLocale( 934 ) );
         m_status_tv->textStorageChanged();
         m_aguix.Flush();
         return;
@@ -738,16 +761,16 @@ void VolumeManagerUI::handlePopupMsg( AGMessage *msg )
 void VolumeManagerUI::eject( HWVolume &vol )
 {
     m_win->setCursor( AGUIX::WAIT_CURSOR );
-    m_status_info.setContent( catalog.getLocale( 918 ) );
+    m_status_info->setContent( catalog.getLocale( 918 ) );
     m_status_tv->textStorageChanged();
     m_aguix.Flush();
     
     std::string error;
     
     if ( m_hwman.eject( vol, error ) == 0 ) {
-	m_status_info.setContent( catalog.getLocale( 919 ) );
+        m_status_info->setContent( catalog.getLocale( 919 ) );
     } else {
-	m_status_info.setContent( error );
+        m_status_info->setContent( error );
     }
     m_status_tv->textStorageChanged();
     
@@ -762,16 +785,16 @@ void VolumeManagerUI::eject( HWVolume &vol )
 void VolumeManagerUI::closeTray( HWVolume &vol )
 {
     m_win->setCursor( AGUIX::WAIT_CURSOR );
-    m_status_info.setContent( catalog.getLocale( 916 ) );
+    m_status_info->setContent( catalog.getLocale( 916 ) );
     m_status_tv->textStorageChanged();
     m_aguix.Flush();
     
     std::string error;
     
     if ( m_hwman.closeTray( vol, error ) == 0 ) {
-	m_status_info.setContent( catalog.getLocale( 917 ) );
+        m_status_info->setContent( catalog.getLocale( 917 ) );
     } else {
-	m_status_info.setContent( error );
+        m_status_info->setContent( error );
     }
     m_status_tv->textStorageChanged();
     
@@ -825,9 +848,9 @@ void VolumeManagerUI::ejectOrCloseTray( const menu_command_t &menu_command )
         }
     } else {
         if ( menu_command == VOLMANUI_MENU_EJECT ) {
-            m_status_info.setContent( catalog.getLocale( 931 ) );
+            m_status_info->setContent( catalog.getLocale( 931 ) );
         } else {
-            m_status_info.setContent( catalog.getLocale( 932 ) );
+            m_status_info->setContent( catalog.getLocale( 932 ) );
         }
         m_status_tv->textStorageChanged();
         buildEjectMenu( menu_command );
