@@ -887,9 +887,9 @@ void WCFiletype::setMagicPattern( const std::string &pat )
 
 bool WCFiletype::magicMatch( const std::string &match_string )
 {
-    if ( m_magic_matcher.getVal() == NULL ) {
+    if ( m_magic_matcher.get() == NULL ) {
         //TODO also support regexs matches
-        m_magic_matcher = new StringMatcherFNMatch();
+        m_magic_matcher.reset( new StringMatcherFNMatch() );
         m_magic_matcher->setMatchString( m_magic_pattern );
         m_magic_matcher->setMatchCaseSensitive( m_magic_ignore_case ? false : true );
     }
