@@ -32,6 +32,7 @@
 #include "stringcomparator.hh"
 #include "wconfig_types.hh"
 #include "wconfig_initial_command.hh"
+#include "wconfig_kvp_pool.hh"
 
 class Worker;
 class WCPath;
@@ -48,7 +49,11 @@ class List;
 class WConfig
 {
 public:
-  typedef enum {CLOCKBAR_MODE_TIMERAM=0,CLOCKBAR_MODE_TIME,CLOCKBAR_MODE_VERSION,CLOCKBAR_MODE_EXTERN} clockbar_mode_t;
+  typedef enum { CLOCKBAR_MODE_TIMERAM = 0,
+                 CLOCKBAR_MODE_TIME,
+                 CLOCKBAR_MODE_VERSION,
+                 CLOCKBAR_MODE_EXTERN,
+                 CLOCKBAR_MODE_CUSTOM } clockbar_mode_t;
 
   WConfig(Worker *);
   ~WConfig();
@@ -100,8 +105,10 @@ public:
   clockbar_mode_t getClockbarMode();
   void setClockbarUpdatetime(int);
   int getClockbarUpdatetime();
-  void setClockbarCommand(const char *);
-  const char *getClockbarCommand();
+    void setClockbarCommand( const std::string & );
+    const std::string &getClockbarCommand() const;
+    void setClockbarCustom( const std::string &, uint8_t variant );
+    const std::string &getClockbarCustom( uint8_t variant ) const;
   void setClockbarHints( bool );
   bool getClockbarHints();
 
@@ -361,6 +368,9 @@ public:
     const std::string getDisableBGCheckPrefix() const;
 
     std::string queryNewActionName() const;
+
+    const WConfigKVPPool &getKVPPool() const;
+    void setKVPPool( const WConfigKVPPool &kvp );
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -378,7 +388,8 @@ protected:
   List *buttons; // Elemente sind WCButton
   clockbar_mode_t clockbar_mode;
   int clockbar_updatetime;
-  char *clockbar_command;
+    std::string clockbar_command;
+    std::string m_clockbar_custom[2];
   bool m_clockbar_hints;
 
     std::list< WConfigTypes::dont_check_dir > m_dont_check_dirs;
@@ -520,6 +531,8 @@ protected:
     WConfigInitialCommand m_initial_command;
 
     std::string m_disable_bg_check_prefix;
+
+    WConfigKVPPool m_kvp_pool;
 };
 
 extern WConfig *wconfig;
