@@ -1,6 +1,6 @@
 /* wconfig_button.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -42,7 +42,7 @@ ButtonPanel::ButtonPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel
   maxbank = _baseconfig.getButtons()->size() / banksize;
 
   extmode = false;
-  mode = 0;
+  m_mode = 0;
   selindex = -1;
 }
 
@@ -295,28 +295,28 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
         updateBankStr();
       }
     } else if ( msg.button.button == copyb ) {
-      if ( ( mode == 1 ) || ( mode == 2 ) ) {
+      if ( ( m_mode == 1 ) || ( m_mode == 2 ) ) {
         sbsb->setText( catalog.getLocale( 53 ) );
-        mode = 0;
+        setMode( 0 );
       } else {
         sbsb->setText( catalog.getLocale( 54 ) );
-        mode = 1;
+        setMode( 1 );
       }
     } else if ( msg.button.button == swapb ) {
-      if ( ( mode == 3 ) || ( mode == 4 ) ) {
+      if ( ( m_mode == 3 ) || ( m_mode == 4 ) ) {
         sbsb->setText( catalog.getLocale( 53 ) );
-        mode = 0;
+        setMode( 0 );
       } else {
         sbsb->setText( catalog.getLocale( 56 ) );
-        mode = 3;
+        setMode( 3 );
       }
     } else if ( msg.button.button == delb ) {
-      if ( mode == 5 ) {
+      if ( m_mode == 5 ) {
         sbsb->setText( catalog.getLocale( 53 ) );
-        mode = 0;
+        setMode( 0 );
       } else {
         sbsb->setText( catalog.getLocale( 58 ) );
-        mode = 5;
+        setMode( 5 );
       }
     } else {
       int t1, t2, t3;
@@ -328,11 +328,11 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
         if ( bbs[t3][t2] == msg.button.button ) {
           int s1 = t1 + banknr * banksize;
           WCButton *b1, *b2;
-          switch ( mode ) {
+          switch ( m_mode ) {
             case 1:
               selindex = s1;
               sbsb->setText( catalog.getLocale( 55 ) );
-              mode = 2;
+              setMode( 2 );
               break;
             case 2:
               // copy selindex -> s1
@@ -346,16 +346,16 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
               showButtonBank();
               if ( extmode == true ) {
                 sbsb->setText( catalog.getLocale( 54 ) );
-                mode = 1;
+                setMode( 1 );
               } else {
                 sbsb->setText( catalog.getLocale( 53 ) );
-                mode = 0;
+                setMode( 0 );
               }
               break;
             case 3:
               selindex = s1;
               sbsb->setText( catalog.getLocale( 57 ) );
-              mode = 4;
+              setMode( 4 );
               break;
             case 4:
               // swap s1 <-> selindex
@@ -365,10 +365,10 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
               showButtonBank();
               if ( extmode == true ) {
                 sbsb->setText( catalog.getLocale( 56 ) );
-                mode = 3;
+                setMode( 3 );
               } else {
                 sbsb->setText( catalog.getLocale( 53 ) );
-                mode = 0;
+                setMode( 0 );
               }
               break;
             case 5:
@@ -379,7 +379,7 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
               showButtonBank();
               if ( extmode == false ) {
                 sbsb->setText( catalog.getLocale( 53 ) );
-                mode = 0;
+                setMode( 0 );
               }
               break;
             default:
@@ -404,7 +404,7 @@ void ButtonPanel::run( Widget *elem, const AGMessage &msg )
   } else if ( msg.type == AG_KEYPRESSED ) {
     if ( msg.key.key == XK_Escape ) {
       sbsb->setText( catalog.getLocale( 53 ) );
-      mode = 0;
+      setMode( 0 );
     }
   }
 }
@@ -469,3 +469,19 @@ void ButtonPanel::updateBankStr()
   sprintf( bankstr, "%2d", maxbank );
   maxbankt->setText( bankstr );
 }
+
+bool ButtonPanel::escapeInUse()
+{
+    // return current value and check if mode is still in use
+    bool res = m_escape_active;
+
+    if ( m_mode == 0 ) m_escape_active = false;
+
+    return res;
+}
+
+void ButtonPanel::setMode( int m )
+{
+    if ( m != 0 ) m_escape_active = true;
+    m_mode = m;
+}
