@@ -22,7 +22,7 @@
 #include "wconfig_cachesize.hh"
 #include "wconfig.h"
 #include "worker_locale.h"
-#include <aguix/stringgadget.h>
+#include "aguix/stringgadget.h"
 
 CacheSizePanel::CacheSizePanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
