@@ -87,7 +87,7 @@ int ImExportPanel::saveValues()
   return 0;
 }
 
-void ImExportPanel::run( Widget *elem, AGMessage &msg )
+void ImExportPanel::run( Widget *elem, const AGMessage &msg )
 {
   bool import_buttons = false, import_hotkeys = false, import_filetypes = false;
   int erg = 0;
