@@ -258,7 +258,7 @@ int VolManPanel::saveValues()
     return 0;
 }
 
-void VolManPanel::run( Widget *elem, AGMessage &msg )
+void VolManPanel::run( Widget *elem, const AGMessage &msg )
 {
     if ( msg.type == AG_BUTTONCLICKED ) {
         FlagReplacer::FlagHelp flags;
