@@ -1,6 +1,6 @@
 /* workerinitialsettings.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010 Ralf Hoffmann.
+ * Copyright (C) 2010-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,7 @@
 
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
+#include "nwc_fsentry.hh"
 
 WorkerInitialSettings *WorkerInitialSettings::m_instance = NULL;
 
@@ -38,6 +39,22 @@ WorkerInitialSettings::WorkerInitialSettings()
         // in this case I will quit here
         exit ( 20 );
     }
+
+    // be backward compatible, accept $HOME/.worker dir
+    if ( NWC::FSEntry( m_config_base_dir ).entryExists() ) {
+        return;
+    }
+
+    char *xdg_home = getenv( "XDG_CONFIG_HOME" );
+    if ( xdg_home && strlen( xdg_home ) > 0 ) {
+        m_config_base_dir = NWC::Path::join( xdg_home, "worker" );
+    } else {
+        std::string xdg_config_dir = NWC::Path::join( homestr, ".config" );
+
+        if ( NWC::FSEntry( xdg_config_dir ).entryExists() ) {
+            m_config_base_dir = NWC::Path::join( xdg_config_dir, "worker" );
+        }
+    }
 }
 
 WorkerInitialSettings::~WorkerInitialSettings()
