@@ -1,6 +1,6 @@
 /* wpucontext.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2021 Ralf Hoffmann.
+ * Copyright (C) 2002-2023 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -61,11 +61,6 @@ class WPUProgressCallback : public CopyfileProgressCallback
 class WPUStack
 {
 public:
-  WPUStack();
-  ~WPUStack();
-  WPUStack( const WPUStack &other );
-  WPUStack &operator=( const WPUStack &other );
-
   void push( const std::string &elem );
   std::string pop();
   std::string top() const;
@@ -81,8 +76,11 @@ class WPUContext
 public:
   WPUContext( Worker *, const command_list_t &coms, ActionMessage *msg );
   ~WPUContext();
-  WPUContext( const WPUContext &other );
-  WPUContext &operator=( const WPUContext &other );
+    WPUContext( const WPUContext &other ) = delete;
+    WPUContext &operator=( const WPUContext &other ) = delete;
+
+    WPUContext( WPUContext &other,
+                ActionMessage *msg );
 
   int continueAtLabel( const char *label );
   void push( int nr, std::string elem );
@@ -159,17 +157,15 @@ public:
     enum ifp_t token;
   };
   
-  int filelistSize( bool other );
-  int filelistRealSize( bool other );
+    bool filelistModified( bool other, bool reset );
 
   std::string getTempName4File( const char *filename );
 
     const std::string &getPathDBFilename() const;
 private:
-  WPUStack **stacks;
+    std::shared_ptr< std::vector< WPUStack > > m_stacks;
   command_list_t acoms;
   size_t pc;
-  int nr_of_stacks;
   void buildStack( int nr );
   
   NMExtList *extlist[2];
@@ -246,6 +242,7 @@ private:
   parse_com_str_t parseComStr( const char *sstr, int maxlen,
                                bool quote, std::string &return_str );
   char *StringRequest( const char *sstr, int maxlen );
+    std::shared_ptr< std::vector< WPUStack > > getStacks();
 
   std::string m_base_dir;
 
